# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountMeterResponse(Model):
    """AccountMeterResponse.

    :param account_meter_id: The account meter identifier <span
     class='property-internal'>Required (defined)</span>
    :type account_meter_id: int
    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param begin_date: The beginning date and time for this account meter
     relationship <span class='property-internal'>Required (defined)</span>
    :type begin_date: datetime
    :param end_date: The ending date and time for this account meter
     relationship <span class='property-internal'>Required (defined)</span>
    :type end_date: datetime
    :param general_ledger:
    :type general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    :param vendor_type:
    :type vendor_type: ~energycap.sdk.models.VendorTypeChild
    :param deregulated: Indicates if the account meter is deregulated <span
     class='property-internal'>Required (defined)</span>
    :type deregulated: bool
    :param form_templates: The template assigned to this account meter <span
     class='property-internal'>Required (defined)</span>
    :type form_templates: list[~energycap.sdk.models.FormTemplateChild]
    :param rates: The rate assigned to this account meter <span
     class='property-internal'>Required (defined)</span>
    :type rates: list[~energycap.sdk.models.AccountRateChild]
    """

    _attribute_map = {
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'general_ledger': {'key': 'generalLedger', 'type': 'GeneralLedgerChild'},
        'vendor_type': {'key': 'vendorType', 'type': 'VendorTypeChild'},
        'deregulated': {'key': 'deregulated', 'type': 'bool'},
        'form_templates': {'key': 'formTemplates', 'type': '[FormTemplateChild]'},
        'rates': {'key': 'rates', 'type': '[AccountRateChild]'},
    }

    def __init__(self, *, account_meter_id: int=None, account=None, meter=None, begin_date=None, end_date=None, general_ledger=None, vendor_type=None, deregulated: bool=None, form_templates=None, rates=None, **kwargs) -> None:
        super(AccountMeterResponse, self).__init__(**kwargs)
        self.account_meter_id = account_meter_id
        self.account = account
        self.meter = meter
        self.begin_date = begin_date
        self.end_date = end_date
        self.general_ledger = general_ledger
        self.vendor_type = vendor_type
        self.deregulated = deregulated
        self.form_templates = form_templates
        self.rates = rates



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeneralLedgerResponse(Model):
    """GeneralLedgerResponse.

    :param general_ledger_id: General Ledger Identifier
    :type general_ledger_id: int
    :param general_ledger_code: Unique code for the general ledger
    :type general_ledger_code: str
    :param sub_codes: List of 20 subCodes with their index, name, and value
    :type sub_codes: list[~energycap.sdk.models.GLSubCodeChild]
    """

    _attribute_map = {
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'sub_codes': {'key': 'subCodes', 'type': '[GLSubCodeChild]'},
    }

    def __init__(self, **kwargs):
        super(GeneralLedgerResponse, self).__init__(**kwargs)
        self.general_ledger_id = kwargs.get('general_ledger_id', None)
        self.general_ledger_code = kwargs.get('general_ledger_code', None)
        self.sub_codes = kwargs.get('sub_codes', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FloorAreaSplitResponse(Model):
    """FloorAreaSplitResponse.

    :param destination_account:
    :type destination_account: ~energycap.sdk.models.AccountChildWithType
    :param destination_meter:
    :type destination_meter: ~energycap.sdk.models.MeterChild
    :param destination_place:
    :type destination_place: ~energycap.sdk.models.PlaceChildWithFloorArea
    :param weighting_factor: Weighting factor to apply in floor area bill
     split for this account and meter
    :type weighting_factor: float
    :param split_percentage: Fixed percentage to apply in bill split for this
     account and meter
    :type split_percentage: float
    """

    _attribute_map = {
        'destination_account': {'key': 'destinationAccount', 'type': 'AccountChildWithType'},
        'destination_meter': {'key': 'destinationMeter', 'type': 'MeterChild'},
        'destination_place': {'key': 'destinationPlace', 'type': 'PlaceChildWithFloorArea'},
        'weighting_factor': {'key': 'weightingFactor', 'type': 'float'},
        'split_percentage': {'key': 'splitPercentage', 'type': 'float'},
    }

    def __init__(self, *, destination_account=None, destination_meter=None, destination_place=None, weighting_factor: float=None, split_percentage: float=None, **kwargs) -> None:
        super(FloorAreaSplitResponse, self).__init__(**kwargs)
        self.destination_account = destination_account
        self.destination_meter = destination_meter
        self.destination_place = destination_place
        self.weighting_factor = weighting_factor
        self.split_percentage = split_percentage



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilterDataResponse(Model):
    """FilterDataResponse.

    :param value:
    :type value: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, value: str=None, **kwargs) -> None:
        super(FilterDataResponse, self).__init__(**kwargs)
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionApprove(Model):
    """BillActionApprove.

    :param ids:  <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type ids: list[int]
    :param approve:  <span class='property-internal'>Required (defined)</span>
    :type approve: bool
    """

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
        'approve': {'key': 'approve', 'type': 'bool'},
    }

    def __init__(self, *, ids=None, approve: bool=None, **kwargs) -> None:
        super(BillActionApprove, self).__init__(**kwargs)
        self.ids = ids
        self.approve = approve



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class QuickReport(Model):
    """QuickReport.

    :param report_code: Report code of the report to execute
    :type report_code: str
    :param file_name: File name that the report file will receive
    :type file_name: str
    :param filters: The filters to apply to this execution of the report. They
     will not be saved, and stored filters will not be honored.
    :type filters: list[~energycap.sdk.models.QuickFilter]
    """

    _attribute_map = {
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'file_name': {'key': 'fileName', 'type': 'str'},
        'filters': {'key': 'filters', 'type': '[QuickFilter]'},
    }

    def __init__(self, *, report_code: str=None, file_name: str=None, filters=None, **kwargs) -> None:
        super(QuickReport, self).__init__(**kwargs)
        self.report_code = report_code
        self.file_name = file_name
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupDigestBenchmarkRankingResponse(Model):
    """PlaceGroupDigestBenchmarkRankingResponse.

    :param high_cost: The highest cost for this group
    :type high_cost: float
    :param low_cost: The lowest cost for this group
    :type low_cost: float
    :param average_cost: The average cost for this group
    :type average_cost: float
    :param median_cost: The median cost for this group
    :type median_cost: float
    :param high_use: The highest use for this group
    :type high_use: float
    :param low_use: The lowest use for this group
    :type low_use: float
    :param average_use: The average use for this group
    :type average_use: float
    :param median_use: The median use for this group
    :type median_use: float
    :param high_value: The highest benchmark value for this group
    :type high_value: float
    :param low_value: The lowest benchmark value for this group
    :type low_value: float
    :param median_value: The median benchmark value for this group
    :type median_value: float
    :param results:
    :type results:
     list[~energycap.sdk.models.PlaceGroupDigestBenchmarkRankingChild]
    :param place_group_id:
    :type place_group_id: int
    :param place_group_code:
    :type place_group_code: str
    :param place_group_info:
    :type place_group_info: str
    :param place_group_display: This is the user's preferred way of viewing
     this entity - could be code or info based on the master "data object view"
     setting in DB
    :type place_group_display: str
    :param benchmark_unit: This will provide the benchmark unit eg:MMBTU/ft²
     or $/day
    :type benchmark_unit: str
    :param benchmark_factor_unit: This will provide the unit for the
     benchmarking factor eg:ft² or day
    :type benchmark_factor_unit: str
    :param benchmark_value_unit: This will provide the unit for the benchmark
     value eg:$ for cost/day, MMBTU for annualized use/area
    :type benchmark_value_unit: str
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    """

    _attribute_map = {
        'high_cost': {'key': 'highCost', 'type': 'float'},
        'low_cost': {'key': 'lowCost', 'type': 'float'},
        'average_cost': {'key': 'averageCost', 'type': 'float'},
        'median_cost': {'key': 'medianCost', 'type': 'float'},
        'high_use': {'key': 'highUse', 'type': 'float'},
        'low_use': {'key': 'lowUse', 'type': 'float'},
        'average_use': {'key': 'averageUse', 'type': 'float'},
        'median_use': {'key': 'medianUse', 'type': 'float'},
        'high_value': {'key': 'highValue', 'type': 'float'},
        'low_value': {'key': 'lowValue', 'type': 'float'},
        'median_value': {'key': 'medianValue', 'type': 'float'},
        'results': {'key': 'results', 'type': '[PlaceGroupDigestBenchmarkRankingChild]'},
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'place_group_code': {'key': 'placeGroupCode', 'type': 'str'},
        'place_group_info': {'key': 'placeGroupInfo', 'type': 'str'},
        'place_group_display': {'key': 'placeGroupDisplay', 'type': 'str'},
        'benchmark_unit': {'key': 'benchmarkUnit', 'type': 'str'},
        'benchmark_factor_unit': {'key': 'benchmarkFactorUnit', 'type': 'str'},
        'benchmark_value_unit': {'key': 'benchmarkValueUnit', 'type': 'str'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, *, high_cost: float=None, low_cost: float=None, average_cost: float=None, median_cost: float=None, high_use: float=None, low_use: float=None, average_use: float=None, median_use: float=None, high_value: float=None, low_value: float=None, median_value: float=None, results=None, place_group_id: int=None, place_group_code: str=None, place_group_info: str=None, place_group_display: str=None, benchmark_unit: str=None, benchmark_factor_unit: str=None, benchmark_value_unit: str=None, use_unit=None, cost_unit=None, updated=None, **kwargs) -> None:
        super(PlaceGroupDigestBenchmarkRankingResponse, self).__init__(**kwargs)
        self.high_cost = high_cost
        self.low_cost = low_cost
        self.average_cost = average_cost
        self.median_cost = median_cost
        self.high_use = high_use
        self.low_use = low_use
        self.average_use = average_use
        self.median_use = median_use
        self.high_value = high_value
        self.low_value = low_value
        self.median_value = median_value
        self.results = results
        self.place_group_id = place_group_id
        self.place_group_code = place_group_code
        self.place_group_info = place_group_info
        self.place_group_display = place_group_display
        self.benchmark_unit = benchmark_unit
        self.benchmark_factor_unit = benchmark_factor_unit
        self.benchmark_value_unit = benchmark_value_unit
        self.use_unit = use_unit
        self.cost_unit = cost_unit
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagEventChild(Model):
    """FlagEventChild.

    :param flag_event_id: The flag event identifier
    :type flag_event_id: int
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: Date that this flag event was created
    :type created_date: datetime
    :param comment: Comment about the flag event
    :type comment: str
    :param description: Description of the flag event
    :type description: str
    :param flag_action:
    :type flag_action: ~energycap.sdk.models.FlagActionChild
    """

    _attribute_map = {
        'flag_event_id': {'key': 'flagEventId', 'type': 'int'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'comment': {'key': 'comment', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'flag_action': {'key': 'flagAction', 'type': 'FlagActionChild'},
    }

    def __init__(self, **kwargs):
        super(FlagEventChild, self).__init__(**kwargs)
        self.flag_event_id = kwargs.get('flag_event_id', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_date = kwargs.get('created_date', None)
        self.comment = kwargs.get('comment', None)
        self.description = kwargs.get('description', None)
        self.flag_action = kwargs.get('flag_action', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributeAccountChargesToBillsRequest(Model):
    """DistributeAccountChargesToBillsRequest.

    :param bill_ids: Bill IDs for which account charges will be proportionally
     distributed to the meters <span class='property-internal'>Cannot be
     Empty</span> <span class='property-internal'>Required (defined)</span>
    :type bill_ids: list[int]
    :param split_basis:
    :type split_basis: int
    """

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'split_basis': {'key': 'splitBasis', 'type': 'int'},
    }

    def __init__(self, *, bill_ids=None, split_basis: int=None, **kwargs) -> None:
        super(DistributeAccountChargesToBillsRequest, self).__init__(**kwargs)
        self.bill_ids = bill_ids
        self.split_basis = split_basis



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillSplitDetailsResponse(Model):
    """Details of the bill split
    FixedPercentageSplit, FloorAreaSplit, and DynamicPercentageSplit are
    mutually exclusive
    Only 1 of these properties will have a value.

    :param version:
    :type version: ~energycap.sdk.models.DistributionVersionResponse
    :param fixed_percentage_split: Populate if setting up a fixed percentage
     split.
    :type fixed_percentage_split:
     list[~energycap.sdk.models.FixedPercentageResponse]
    :param floor_area_split: Populate if setting up a dynamic percentage split
     based on the building floor area with weighting factor applied.
    :type floor_area_split: list[~energycap.sdk.models.FloorAreaSplitResponse]
    :param dynamic_percentage_split:
    :type dynamic_percentage_split:
     ~energycap.sdk.models.DynamicPercentageBillSplitResponse
    """

    _attribute_map = {
        'version': {'key': 'version', 'type': 'DistributionVersionResponse'},
        'fixed_percentage_split': {'key': 'fixedPercentageSplit', 'type': '[FixedPercentageResponse]'},
        'floor_area_split': {'key': 'floorAreaSplit', 'type': '[FloorAreaSplitResponse]'},
        'dynamic_percentage_split': {'key': 'dynamicPercentageSplit', 'type': 'DynamicPercentageBillSplitResponse'},
    }

    def __init__(self, *, version=None, fixed_percentage_split=None, floor_area_split=None, dynamic_percentage_split=None, **kwargs) -> None:
        super(BillSplitDetailsResponse, self).__init__(**kwargs)
        self.version = version
        self.fixed_percentage_split = fixed_percentage_split
        self.floor_area_split = floor_area_split
        self.dynamic_percentage_split = dynamic_percentage_split



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OkResult(Model):
    """OkResult.

    :param status_code:
    :type status_code: int
    """

    _attribute_map = {
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self, *, status_code: int=None, **kwargs) -> None:
        super(OkResult, self).__init__(**kwargs)
        self.status_code = status_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostSavingsUnit(Model):
    """CostSavingsUnit.

    :param cost_savings_unit_id: The cost savings unit identifier
    :type cost_savings_unit_id: int
    :param cost_savings_unit_code: The cost savings unit code
    :type cost_savings_unit_code: str
    :param cost_savings_unit_info: The cost savings unit information
    :type cost_savings_unit_info: str
    """

    _attribute_map = {
        'cost_savings_unit_id': {'key': 'costSavingsUnitId', 'type': 'int'},
        'cost_savings_unit_code': {'key': 'costSavingsUnitCode', 'type': 'str'},
        'cost_savings_unit_info': {'key': 'costSavingsUnitInfo', 'type': 'str'},
    }

    def __init__(self, *, cost_savings_unit_id: int=None, cost_savings_unit_code: str=None, cost_savings_unit_info: str=None, **kwargs) -> None:
        super(CostSavingsUnit, self).__init__(**kwargs)
        self.cost_savings_unit_id = cost_savings_unit_id
        self.cost_savings_unit_code = cost_savings_unit_code
        self.cost_savings_unit_info = cost_savings_unit_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupRequest(Model):
    """UserGroupRequest.

    All required parameters must be populated in order to send to Azure.

    :param user_group_name: Required. The user group name <span
     class='property-internal'>Must be between 0 and 64 characters</span> <span
     class='property-internal'>Required</span>
    :type user_group_name: str
    :param description: A description of the user group <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type description: str
    :param members: List of system user ids in the group
     Hidden users cannot be added to groups
     On PUT request, if this property is null or not passed the group
     membership will not change
     To remove all members pass an empty list
    :type members: list[int]
    :param new_user_email: List of new users to create and add to the group
     The email cannot be currently used by another user
     Users are created as limited users with the Contact role and default
     topmost
    :type new_user_email: list[str]
    """

    _validation = {
        'user_group_name': {'required': True, 'max_length': 64, 'min_length': 0},
        'description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'members': {'key': 'members', 'type': '[int]'},
        'new_user_email': {'key': 'newUserEmail', 'type': '[str]'},
    }

    def __init__(self, *, user_group_name: str, description: str=None, members=None, new_user_email=None, **kwargs) -> None:
        super(UserGroupRequest, self).__init__(**kwargs)
        self.user_group_name = user_group_name
        self.description = description
        self.members = members
        self.new_user_email = new_user_email



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificReportResponse(Model):
    """SpecificReportResponse.

    :param specific_report_id: Unique identifier for the report
    :type specific_report_id: int
    :param base_report:
    :type base_report: ~energycap.sdk.models.ReportChild
    :param specific_report_code: Report code
    :type specific_report_code: str
    :param specific_report_info: Report name
    :type specific_report_info: str
    :param last_viewed: Last time this report was run
    :type last_viewed: datetime
    :param recommended: Indicates if this is a recommended report
    :type recommended: bool
    :param report_category:
    :type report_category: ~energycap.sdk.models.ReportCategoryChild
    :param description: The report description
    :type description: str
    :param visible: Indicates if this report is visible to the current user
    :type visible: bool
    :param shared: Indicates if this report is shared
    :type shared: bool
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param subscription:
    :type subscription: ~energycap.sdk.models.ReportSubscriptionChild
    :param related_reports: List of reports related to this report
    :type related_reports: list[~energycap.sdk.models.RelatedReportResponse]
    """

    _attribute_map = {
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'base_report': {'key': 'baseReport', 'type': 'ReportChild'},
        'specific_report_code': {'key': 'specificReportCode', 'type': 'str'},
        'specific_report_info': {'key': 'specificReportInfo', 'type': 'str'},
        'last_viewed': {'key': 'lastViewed', 'type': 'iso-8601'},
        'recommended': {'key': 'recommended', 'type': 'bool'},
        'report_category': {'key': 'reportCategory', 'type': 'ReportCategoryChild'},
        'description': {'key': 'description', 'type': 'str'},
        'visible': {'key': 'visible', 'type': 'bool'},
        'shared': {'key': 'shared', 'type': 'bool'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'subscription': {'key': 'subscription', 'type': 'ReportSubscriptionChild'},
        'related_reports': {'key': 'relatedReports', 'type': '[RelatedReportResponse]'},
    }

    def __init__(self, **kwargs):
        super(SpecificReportResponse, self).__init__(**kwargs)
        self.specific_report_id = kwargs.get('specific_report_id', None)
        self.base_report = kwargs.get('base_report', None)
        self.specific_report_code = kwargs.get('specific_report_code', None)
        self.specific_report_info = kwargs.get('specific_report_info', None)
        self.last_viewed = kwargs.get('last_viewed', None)
        self.recommended = kwargs.get('recommended', None)
        self.report_category = kwargs.get('report_category', None)
        self.description = kwargs.get('description', None)
        self.visible = kwargs.get('visible', None)
        self.shared = kwargs.get('shared', None)
        self.user = kwargs.get('user', None)
        self.subscription = kwargs.get('subscription', None)
        self.related_reports = kwargs.get('related_reports', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceMetricsRequest(Model):
    """EnergyStarPlaceMetricsRequest.

    All required parameters must be populated in order to send to Azure.

    :param begin_period: Required. The begin period for updating ENERGY STAR
     metrics <span class='property-internal'>Required</span>
    :type begin_period: int
    :param end_period: The end period for updating ENERGY STAR metrics
     If null, metrics will only be retrieved for the period specified in
     BeginPeriod
    :type end_period: int
    :param place_ids: Required. List of place identifiers to for which to
     update metrics <span class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type place_ids: list[int]
    """

    _validation = {
        'begin_period': {'required': True},
        'place_ids': {'required': True},
    }

    _attribute_map = {
        'begin_period': {'key': 'beginPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
        'place_ids': {'key': 'placeIds', 'type': '[int]'},
    }

    def __init__(self, *, begin_period: int, place_ids, end_period: int=None, **kwargs) -> None:
        super(EnergyStarPlaceMetricsRequest, self).__init__(**kwargs)
        self.begin_period = begin_period
        self.end_period = end_period
        self.place_ids = place_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Estimated(Model):
    """Estimated.

    All required parameters must be populated in order to send to Azure.

    :param column_number: Required. Column number specifying where to look for
     the estimated indicator <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 1 and 2147483647</span>
    :type column_number: int
    :param indicator: Required. The string used to indicate the reading is
     estimated
     If this value is found in the column number specified the reading will be
     marked as estimated
     Example: e, E, 1, 0, est, *, this is my estimated read <span
     class='property-internal'>Required</span>
    :type indicator: str
    """

    _validation = {
        'column_number': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'indicator': {'required': True},
    }

    _attribute_map = {
        'column_number': {'key': 'columnNumber', 'type': 'int'},
        'indicator': {'key': 'indicator', 'type': 'str'},
    }

    def __init__(self, *, column_number: int, indicator: str, **kwargs) -> None:
        super(Estimated, self).__init__(**kwargs)
        self.column_number = column_number
        self.indicator = indicator



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupDigestDemandRankingChild(Model):
    """MeterGroupDigestDemandRankingChild.

    :param cost:
    :type cost: float
    :param value:
    :type value: float
    :param meter_id:
    :type meter_id: int
    :param meter_code:
    :type meter_code: str
    :param meter_info:
    :type meter_info: str
    :param meter_display:
    :type meter_display: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param include_in_charts:
    :type include_in_charts: bool
    :param active: Indicates whether the Meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the Meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the Meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the Meter is a child of a
     split
    :type is_split_child_meter: bool
    """

    _attribute_map = {
        'cost': {'key': 'cost', 'type': 'float'},
        'value': {'key': 'value', 'type': 'float'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_display': {'key': 'meterDisplay', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, *, cost: float=None, value: float=None, meter_id: int=None, meter_code: str=None, meter_info: str=None, meter_display: str=None, commodity=None, include_in_charts: bool=None, active: bool=None, is_calculated_meter: bool=None, is_split_parent_meter: bool=None, is_split_child_meter: bool=None, **kwargs) -> None:
        super(MeterGroupDigestDemandRankingChild, self).__init__(**kwargs)
        self.cost = cost
        self.value = value
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_display = meter_display
        self.commodity = commodity
        self.include_in_charts = include_in_charts
        self.active = active
        self.is_calculated_meter = is_calculated_meter
        self.is_split_parent_meter = is_split_parent_meter
        self.is_split_child_meter = is_split_child_meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorRequest(Model):
    """VendorRequest.

    All required parameters must be populated in order to send to Azure.

    :param vendor_code: Required. The vendor code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type vendor_code: str
    :param vendor_info: Required. The vendor info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type vendor_info: str
    :param website: The vendor's website <span class='property-internal'>Must
     be between 0 and 255 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type website: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param vendor_description: A description of the vendor <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
     <span class='property-internal'>Required (defined)</span>. Default value:
     "Æ" .
    :type vendor_description: str
    """

    _validation = {
        'vendor_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'vendor_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'website': {'max_length': 255, 'min_length': 0},
        'vendor_description': {'max_length': 4000, 'min_length': 0},
    }

    _attribute_map = {
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'website': {'key': 'website', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'vendor_description': {'key': 'vendorDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(VendorRequest, self).__init__(**kwargs)
        self.vendor_code = kwargs.get('vendor_code', None)
        self.vendor_info = kwargs.get('vendor_info', None)
        self.website = kwargs.get('website', None)
        self.address = kwargs.get('address', None)
        self.vendor_description = kwargs.get('vendor_description', "Æ")



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GreenhouseGasAdministrator(Model):
    """GreenhouseGasAdministrator.

    :param manage:
    :type manage: bool
    :param permission_id:
    :type permission_id: int
    :param permission_code:
    :type permission_code: str
    :param permission_name:
    :type permission_name: str
    :param description:
    :type description: str
    :param permission_category_name:
    :type permission_category_name: str
    :param is_licensed:
    :type is_licensed: bool
    """

    _attribute_map = {
        'manage': {'key': 'manage', 'type': 'bool'},
        'permission_id': {'key': 'permissionId', 'type': 'int'},
        'permission_code': {'key': 'permissionCode', 'type': 'str'},
        'permission_name': {'key': 'permissionName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permission_category_name': {'key': 'permissionCategoryName', 'type': 'str'},
        'is_licensed': {'key': 'isLicensed', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(GreenhouseGasAdministrator, self).__init__(**kwargs)
        self.manage = kwargs.get('manage', None)
        self.permission_id = kwargs.get('permission_id', None)
        self.permission_code = kwargs.get('permission_code', None)
        self.permission_name = kwargs.get('permission_name', None)
        self.description = kwargs.get('description', None)
        self.permission_category_name = kwargs.get('permission_category_name', None)
        self.is_licensed = kwargs.get('is_licensed', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationSummary(Model):
    """WeatherStationSummary.

    :param begin_date: Begin date for this weather station
     May differ from the begin date provided by the user if the most recent
     weather reading for this station was earlier.
    :type begin_date: datetime
    :param earliest_reading_date: Earliest reading date imported for this
     weather station
     May differ from the begin date provided by the user if the most recent
     weather reading available for this station was later.
    :type earliest_reading_date: datetime
    :param weather_station_id: Weather station ID
    :type weather_station_id: int
    :param weather_station_code: Weather station code
    :type weather_station_code: str
    :param weather_station_name: Weather station name
    :type weather_station_name: str
    :param base_weather_station_code: Source weather station code (if any)
    :type base_weather_station_code: str
    :param number_of_readings_imported: Number of readings imported
    :type number_of_readings_imported: int
    :param number_of_failed_readings: Number of readings failed to import
    :type number_of_failed_readings: int
    :param channel_id: Channel ID
    :type channel_id: int
    :param channel_code: Channel code
    :type channel_code: str
    :param channel_interval_in_seconds: Channel interval in seconds
    :type channel_interval_in_seconds: int
    """

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'earliest_reading_date': {'key': 'earliestReadingDate', 'type': 'iso-8601'},
        'weather_station_id': {'key': 'weatherStationId', 'type': 'int'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
        'weather_station_name': {'key': 'weatherStationName', 'type': 'str'},
        'base_weather_station_code': {'key': 'baseWeatherStationCode', 'type': 'str'},
        'number_of_readings_imported': {'key': 'numberOfReadingsImported', 'type': 'int'},
        'number_of_failed_readings': {'key': 'numberOfFailedReadings', 'type': 'int'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(WeatherStationSummary, self).__init__(**kwargs)
        self.begin_date = kwargs.get('begin_date', None)
        self.earliest_reading_date = kwargs.get('earliest_reading_date', None)
        self.weather_station_id = kwargs.get('weather_station_id', None)
        self.weather_station_code = kwargs.get('weather_station_code', None)
        self.weather_station_name = kwargs.get('weather_station_name', None)
        self.base_weather_station_code = kwargs.get('base_weather_station_code', None)
        self.number_of_readings_imported = kwargs.get('number_of_readings_imported', None)
        self.number_of_failed_readings = kwargs.get('number_of_failed_readings', None)
        self.channel_id = kwargs.get('channel_id', None)
        self.channel_code = kwargs.get('channel_code', None)
        self.channel_interval_in_seconds = kwargs.get('channel_interval_in_seconds', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributedReportsConfiguration(Model):
    """DistributedReportsConfiguration.

    :param format: Desired format for the resulting report.
     Available options are PDF, Excel, Word, and CSV. Support for each format
     varies by report.
    :type format: str
    :param use_copy: Indicates whether or not to use a copy of the report when
     generating it.
     When set to true, a one-time copy of the requested specific report will be
     created, set with the provided filters, and then deleted afterward.
     This functionality is useful when you want to run a report with a one-time
     filter set, without touching the original report's filters.
    :type use_copy: bool
    :param filters: List of filters to use when executing this report. How
     they are handled depends upon the other configuration options used in this
     request.
    :type filters: list[~energycap.sdk.models.FilterEdit]
    :param clear_filters: Indicates whether or not to clear out stored filters
     for the requested report during execution.
     When set to true, any stored filters for this report will be removed. Only
     filters provided in the Filters property will be applied.
     When set to false, any stored filters will still apply when the report is
     executed.
    :type clear_filters: bool
    :param save_filters: Indicates whether or not to save the filters provided
     in the Filters property.
     When set to true, any filters currently stored for the requested report
     will be overwritten with those provided in the Filters property.
     When set to false, any filters provided in the Filters property will not
     be saved after execution. However, they will be used for this report
     execution.
    :type save_filters: bool
    :param only_send_if_data: Indicates whether or not to email a report if it
     contains no data.
     When set to true, if distributing the requested report to an email list
     and the report contains no data, the report will not be emailed.
     When set to false, if the requested report has no data, it will still be
     sent to the email list.
    :type only_send_if_data: bool
    :param file_name: Filename for the resulting report file. Do not provide
     file type suffix.
     Defaults to {specificReportCode}-{specificReportInfo}{fileNameExtension}
    :type file_name: str
    :param distribution:
    :type distribution: ~energycap.sdk.models.EmailProperties
    """

    _attribute_map = {
        'format': {'key': 'format', 'type': 'str'},
        'use_copy': {'key': 'useCopy', 'type': 'bool'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
        'clear_filters': {'key': 'clearFilters', 'type': 'bool'},
        'save_filters': {'key': 'saveFilters', 'type': 'bool'},
        'only_send_if_data': {'key': 'onlySendIfData', 'type': 'bool'},
        'file_name': {'key': 'fileName', 'type': 'str'},
        'distribution': {'key': 'distribution', 'type': 'EmailProperties'},
    }

    def __init__(self, *, format: str=None, use_copy: bool=None, filters=None, clear_filters: bool=None, save_filters: bool=None, only_send_if_data: bool=None, file_name: str=None, distribution=None, **kwargs) -> None:
        super(DistributedReportsConfiguration, self).__init__(**kwargs)
        self.format = format
        self.use_copy = use_copy
        self.filters = filters
        self.clear_filters = clear_filters
        self.save_filters = save_filters
        self.only_send_if_data = only_send_if_data
        self.file_name = file_name
        self.distribution = distribution



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseGHGScope(Model):
    """PlaceDigestGHGYearlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param ghg_scope_type_code: GHG scope type code
    :type ghg_scope_type_code: str
    :param ghg_scope_type_info: GHG scope type code
    :type ghg_scope_type_info: str
    :param ghg_types: An array of ghg type yearly data
    :type ghg_types:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseGHGType]
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'ghg_scope_type_code': {'key': 'ghgScopeTypeCode', 'type': 'str'},
        'ghg_scope_type_info': {'key': 'ghgScopeTypeInfo', 'type': 'str'},
        'ghg_types': {'key': 'ghgTypes', 'type': '[PlaceDigestGHGYearlyResponseGHGType]'},
    }

    def __init__(self, *, ghg_scope_id: int=None, ghg_scope_code: str=None, ghg_scope_info: str=None, ghg_scope_type_code: str=None, ghg_scope_type_info: str=None, ghg_types=None, **kwargs) -> None:
        super(PlaceDigestGHGYearlyResponseGHGScope, self).__init__(**kwargs)
        self.ghg_scope_id = ghg_scope_id
        self.ghg_scope_code = ghg_scope_code
        self.ghg_scope_info = ghg_scope_info
        self.ghg_scope_type_code = ghg_scope_type_code
        self.ghg_scope_type_info = ghg_scope_type_info
        self.ghg_types = ghg_types



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillPaymentDetailsItem(Model):
    """BillPaymentDetailsItem.

    All required parameters must be populated in order to send to Azure.

    :param bill_id: Required. Identifier for bill to update <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type bill_id: int
    :param check_number: Required. Check number of payment <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type check_number: str
    :param check_date: Required. Date of payment <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type check_date: datetime
    :param pay_status: Required. Payment status indicator <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 10 characters</span> <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 10 characters</span>
    :type pay_status: str
    :param cleared_date: Date payment cleared <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     <span class='property-internal'>Required (defined)</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type cleared_date: datetime
    :param accounting_period: Accounting period in which payment was made
     <span class='property-internal'>Must be between 190001 and 209913</span>
     <span class='property-internal'>Required (defined)</span> <span
     class='property-internal'>Must be between 190001 and 209913</span>
    :type accounting_period: int
    :param comment: Optional description for payment (ignored by importer)
     <span class='property-internal'>Required (defined)</span>
    :type comment: str
    """

    _validation = {
        'bill_id': {'required': True},
        'check_number': {'required': True, 'max_length': 32, 'min_length': 0},
        'check_date': {'required': True},
        'pay_status': {'required': True, 'max_length': 10, 'min_length': 0},
        'accounting_period': {'maximum': 209913, 'minimum': 190001},
    }

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'check_number': {'key': 'checkNumber', 'type': 'str'},
        'check_date': {'key': 'checkDate', 'type': 'iso-8601'},
        'pay_status': {'key': 'payStatus', 'type': 'str'},
        'cleared_date': {'key': 'clearedDate', 'type': 'iso-8601'},
        'accounting_period': {'key': 'accountingPeriod', 'type': 'int'},
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, *, bill_id: int, check_number: str, check_date, pay_status: str, cleared_date=None, accounting_period: int=None, comment: str=None, **kwargs) -> None:
        super(BillPaymentDetailsItem, self).__init__(**kwargs)
        self.bill_id = bill_id
        self.check_number = check_number
        self.check_date = check_date
        self.pay_status = pay_status
        self.cleared_date = cleared_date
        self.accounting_period = accounting_period
        self.comment = comment



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityChild(Model):
    """CommodityChild.

    :param commodity_id: The commodity identifier <span
     class='property-internal'>Required (defined)</span>
    :type commodity_id: int
    :param commodity_code: The commodity code <span
     class='property-internal'>Required (defined)</span>
    :type commodity_code: str
    :param commodity_info: The commodity info <span
     class='property-internal'>Required (defined)</span>
    :type commodity_info: str
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(CommodityChild, self).__init__(**kwargs)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyResponse(Model):
    """ApiKeyResponse.

    :param api_key_id: The identifier of the API key
    :type api_key_id: int
    :param api_key_name: The name of the API key
    :type api_key_name: str
    :param api_key_description: A description of the API key
    :type api_key_description: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The API key creation date
    :type created_date: datetime
    """

    _attribute_map = {
        'api_key_id': {'key': 'apiKeyId', 'type': 'int'},
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(ApiKeyResponse, self).__init__(**kwargs)
        self.api_key_id = kwargs.get('api_key_id', None)
        self.api_key_name = kwargs.get('api_key_name', None)
        self.api_key_description = kwargs.get('api_key_description', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_date = kwargs.get('created_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupPlaceGroupResponse(Model):
    """GroupPlaceGroupResponse.

    :param place_group_id: The place group identifier
    :type place_group_id: int
    :param place_group_code: The place group code
    :type place_group_code: str
    :param place_group_info: The place group info
    :type place_group_info: str
    :param auto_group: Indicates if this place group is an autogroup
    :type auto_group: bool
    :param member_count: The number of places in this group
    :type member_count: int
    :param member_count_with_topmost: The number of places within the
     currently authenticated user's topmost
    :type member_count_with_topmost: int
    :param place_group_category:
    :type place_group_category: ~energycap.sdk.models.PlaceGroupCategoryChild
    :param limit_members_by_topmost: Indicates if the place group has been set
     limit the list of members by the user's topmost
    :type limit_members_by_topmost: bool
    :param user_defined_auto_group: Indicates if this place group is an user
     defined auto group
    :type user_defined_auto_group: bool
    :param user_defined_auto_group_filters: The filters applied to determine
     the members of a user defined auto group
    :type user_defined_auto_group_filters:
     list[~energycap.sdk.models.FilterResponse]
    :param last_updated: The last time a member was inserted, updated, or
     deleted from the group
    :type last_updated: datetime
    """

    _attribute_map = {
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'place_group_code': {'key': 'placeGroupCode', 'type': 'str'},
        'place_group_info': {'key': 'placeGroupInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'member_count': {'key': 'memberCount', 'type': 'int'},
        'member_count_with_topmost': {'key': 'memberCountWithTopmost', 'type': 'int'},
        'place_group_category': {'key': 'placeGroupCategory', 'type': 'PlaceGroupCategoryChild'},
        'limit_members_by_topmost': {'key': 'limitMembersByTopmost', 'type': 'bool'},
        'user_defined_auto_group': {'key': 'userDefinedAutoGroup', 'type': 'bool'},
        'user_defined_auto_group_filters': {'key': 'userDefinedAutoGroupFilters', 'type': '[FilterResponse]'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
    }

    def __init__(self, *, place_group_id: int=None, place_group_code: str=None, place_group_info: str=None, auto_group: bool=None, member_count: int=None, member_count_with_topmost: int=None, place_group_category=None, limit_members_by_topmost: bool=None, user_defined_auto_group: bool=None, user_defined_auto_group_filters=None, last_updated=None, **kwargs) -> None:
        super(GroupPlaceGroupResponse, self).__init__(**kwargs)
        self.place_group_id = place_group_id
        self.place_group_code = place_group_code
        self.place_group_info = place_group_info
        self.auto_group = auto_group
        self.member_count = member_count
        self.member_count_with_topmost = member_count_with_topmost
        self.place_group_category = place_group_category
        self.limit_members_by_topmost = limit_members_by_topmost
        self.user_defined_auto_group = user_defined_auto_group
        self.user_defined_auto_group_filters = user_defined_auto_group_filters
        self.last_updated = last_updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowResponse(Model):
    """ChargebackWorkflowResponse.

    :param chargeback_workflow_steps: List of workflow steps with details
    :type chargeback_workflow_steps:
     list[~energycap.sdk.models.ChargebackWorkflowStep]
    :param chargeback_workflow_id: Identifier for the chargeback workflow
    :type chargeback_workflow_id: int
    :param chargeback_workflow_info: Name given to the chargeback workflow
    :type chargeback_workflow_info: str
    """

    _attribute_map = {
        'chargeback_workflow_steps': {'key': 'chargebackWorkflowSteps', 'type': '[ChargebackWorkflowStep]'},
        'chargeback_workflow_id': {'key': 'chargebackWorkflowId', 'type': 'int'},
        'chargeback_workflow_info': {'key': 'chargebackWorkflowInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ChargebackWorkflowResponse, self).__init__(**kwargs)
        self.chargeback_workflow_steps = kwargs.get('chargeback_workflow_steps', None)
        self.chargeback_workflow_id = kwargs.get('chargeback_workflow_id', None)
        self.chargeback_workflow_info = kwargs.get('chargeback_workflow_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExportWorkflowSettings(Model):
    """ExportWorkflowSettings.

    :param export_mode_enabled:
    :type export_mode_enabled: bool
    :param can_export:
    :type can_export: str
    """

    _attribute_map = {
        'export_mode_enabled': {'key': 'exportModeEnabled', 'type': 'bool'},
        'can_export': {'key': 'canExport', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ExportWorkflowSettings, self).__init__(**kwargs)
        self.export_mode_enabled = kwargs.get('export_mode_enabled', None)
        self.can_export = kwargs.get('can_export', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionLogResponse(Model):
    """ReportDistributionLogResponse.

    :param report_distribution_log_id: The report distribution log identifier
    :type report_distribution_log_id: int
    :param report_distribution:
    :type report_distribution: ~energycap.sdk.models.ReportDistributionChild
    :param begin_date: The date and time the report distribution was started
    :type begin_date: datetime
    :param end_date: The date and time the report distribution was completed
    :type end_date: datetime
    :param status: The status of the report distribution
     Possible values - In Progress, Complete, Not sent, Some reports not sent
    :type status: str
    :param number_of_recipients: The number of unique recipients for the
     report
     If a user is a member of multiple groups assigned to the report
     distribution they will only be counted once
    :type number_of_recipients: int
    """

    _attribute_map = {
        'report_distribution_log_id': {'key': 'reportDistributionLogId', 'type': 'int'},
        'report_distribution': {'key': 'reportDistribution', 'type': 'ReportDistributionChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'status': {'key': 'status', 'type': 'str'},
        'number_of_recipients': {'key': 'numberOfRecipients', 'type': 'int'},
    }

    def __init__(self, *, report_distribution_log_id: int=None, report_distribution=None, begin_date=None, end_date=None, status: str=None, number_of_recipients: int=None, **kwargs) -> None:
        super(ReportDistributionLogResponse, self).__init__(**kwargs)
        self.report_distribution_log_id = report_distribution_log_id
        self.report_distribution = report_distribution
        self.begin_date = begin_date
        self.end_date = end_date
        self.status = status
        self.number_of_recipients = number_of_recipients



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelChild(Model):
    """ChannelChild.

    :param channel_code: The channel code
     Combines
     observationTypeCode:unitCode:observationMethodCode:observationRuleCode:interval
     in minutes
    :type channel_code: str
    :param channel_id: The channel identifier
    :type channel_id: int
    :param interval: The channel interval in seconds.
     Monthly = 2592000
     Weekly = 604800
     Daily = 86400
     Hourly = 3600
     Thirty_Minutes = 1800
     Fifteen_Minutes = 900
    :type interval: int
    """

    _attribute_map = {
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ChannelChild, self).__init__(**kwargs)
        self.channel_code = kwargs.get('channel_code', None)
        self.channel_id = kwargs.get('channel_id', None)
        self.interval = kwargs.get('interval', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillPaymentDetailsResponse(Model):
    """BillPaymentDetailsResponse.

    :param success: Number of successful bill payment detail updates <span
     class='property-internal'>Required (defined)</span>
    :type success: int
    :param failure: Number of unsuccessful bill payment detail updates <span
     class='property-internal'>Required (defined)</span>
    :type failure: int
    :param bill_payment_details_items: List of unsuccessful bill payment
     detail updates with reasons for failure <span
     class='property-internal'>Required (defined)</span>
    :type bill_payment_details_items:
     list[~energycap.sdk.models.BillPaymentDetailsItem]
    """

    _attribute_map = {
        'success': {'key': 'success', 'type': 'int'},
        'failure': {'key': 'failure', 'type': 'int'},
        'bill_payment_details_items': {'key': 'billPaymentDetailsItems', 'type': '[BillPaymentDetailsItem]'},
    }

    def __init__(self, **kwargs):
        super(BillPaymentDetailsResponse, self).__init__(**kwargs)
        self.success = kwargs.get('success', None)
        self.failure = kwargs.get('failure', None)
        self.bill_payment_details_items = kwargs.get('bill_payment_details_items', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationBadgeResponse(Model):
    """NotificationBadgeResponse.

    :param total_notifications: Total of unread and unarchived notifications
    :type total_notifications: int
    :param new_notifications: Total of unread and unarchived notifications
     since the last checked date time
    :type new_notifications: int
    :param last_check_date_time_utc: The date and time in UTC the query to get
     the badge data was run
    :type last_check_date_time_utc: datetime
    """

    _attribute_map = {
        'total_notifications': {'key': 'totalNotifications', 'type': 'int'},
        'new_notifications': {'key': 'newNotifications', 'type': 'int'},
        'last_check_date_time_utc': {'key': 'lastCheckDateTimeUtc', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(NotificationBadgeResponse, self).__init__(**kwargs)
        self.total_notifications = kwargs.get('total_notifications', None)
        self.new_notifications = kwargs.get('new_notifications', None)
        self.last_check_date_time_utc = kwargs.get('last_check_date_time_utc', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectEdit(Model):
    """EnergyProjectEdit.

    All required parameters must be populated in order to send to Azure.

    :param place_id: The place identifier <span
     class='property-internal'>Required (defined)</span>
    :type place_id: int
    :param energy_project_code: Required. The energy project code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type energy_project_code: str
    :param energy_project_info: Required. The energy project info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type energy_project_info: str
    :param installation_begin_date: The energy project installation begin date
     <span class='property-internal'>Required (defined)</span>
    :type installation_begin_date: datetime
    :param installation_end_date: The energy project installation end date
     <span class='property-internal'>Required (defined)</span>
    :type installation_end_date: datetime
    :param installation_cost: The energy project installation cost <span
     class='property-internal'>Required (defined)</span>
    :type installation_cost: float
    :param energy_project_type_code: Required. The energy project type code
     <span class='property-internal'>Required</span>
    :type energy_project_type_code: str
    :param utility_rebate: The rebate amount of energy project <span
     class='property-internal'>Required (defined)</span>
    :type utility_rebate: float
    :param funding_source: The funding source of the project <span
     class='property-internal'>Required (defined)</span>
    :type funding_source: str
    :param project_manager: The project manager of the energy project <span
     class='property-internal'>Required (defined)</span>
    :type project_manager: str
    :param note: The miscellaneous note about the project <span
     class='property-internal'>Required (defined)</span>
    :type note: str
    :param energy_savings: The energy savings amount <span
     class='property-internal'>Required (defined)</span>
    :type energy_savings: float
    :param energy_savings_unit_code: The energy savings unit code <span
     class='property-internal'>Required (defined)</span>
    :type energy_savings_unit_code: str
    :param cost_savings: The cost savings amount <span
     class='property-internal'>Required (defined)</span>
    :type cost_savings: float
    :param cost_savings_unit_code: The cost savings unit code <span
     class='property-internal'>Required (defined)</span>
    :type cost_savings_unit_code: str
    """

    _validation = {
        'energy_project_code': {'required': True, 'max_length': 128, 'min_length': 0},
        'energy_project_info': {'required': True, 'max_length': 128, 'min_length': 0},
        'energy_project_type_code': {'required': True},
    }

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'energy_project_code': {'key': 'energyProjectCode', 'type': 'str'},
        'energy_project_info': {'key': 'energyProjectInfo', 'type': 'str'},
        'installation_begin_date': {'key': 'installationBeginDate', 'type': 'iso-8601'},
        'installation_end_date': {'key': 'installationEndDate', 'type': 'iso-8601'},
        'installation_cost': {'key': 'installationCost', 'type': 'float'},
        'energy_project_type_code': {'key': 'energyProjectTypeCode', 'type': 'str'},
        'utility_rebate': {'key': 'utilityRebate', 'type': 'float'},
        'funding_source': {'key': 'fundingSource', 'type': 'str'},
        'project_manager': {'key': 'projectManager', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'energy_savings': {'key': 'energySavings', 'type': 'float'},
        'energy_savings_unit_code': {'key': 'energySavingsUnitCode', 'type': 'str'},
        'cost_savings': {'key': 'costSavings', 'type': 'float'},
        'cost_savings_unit_code': {'key': 'costSavingsUnitCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergyProjectEdit, self).__init__(**kwargs)
        self.place_id = kwargs.get('place_id', None)
        self.energy_project_code = kwargs.get('energy_project_code', None)
        self.energy_project_info = kwargs.get('energy_project_info', None)
        self.installation_begin_date = kwargs.get('installation_begin_date', None)
        self.installation_end_date = kwargs.get('installation_end_date', None)
        self.installation_cost = kwargs.get('installation_cost', None)
        self.energy_project_type_code = kwargs.get('energy_project_type_code', None)
        self.utility_rebate = kwargs.get('utility_rebate', None)
        self.funding_source = kwargs.get('funding_source', None)
        self.project_manager = kwargs.get('project_manager', None)
        self.note = kwargs.get('note', None)
        self.energy_savings = kwargs.get('energy_savings', None)
        self.energy_savings_unit_code = kwargs.get('energy_savings_unit_code', None)
        self.cost_savings = kwargs.get('cost_savings', None)
        self.cost_savings_unit_code = kwargs.get('cost_savings_unit_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandResponse(Model):
    """CalculatedBillDemandResponse.

    :param readings_from_channel:
    :type readings_from_channel:
     ~energycap.sdk.models.ChannelChildWithObservationType
    :param fixed_demand:
    :type fixed_demand: ~energycap.sdk.models.FixedAmountResponse
    """

    _attribute_map = {
        'readings_from_channel': {'key': 'readingsFromChannel', 'type': 'ChannelChildWithObservationType'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedAmountResponse'},
    }

    def __init__(self, **kwargs):
        super(CalculatedBillDemandResponse, self).__init__(**kwargs)
        self.readings_from_channel = kwargs.get('readings_from_channel', None)
        self.fixed_demand = kwargs.get('fixed_demand', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FileDataTypeResponse(Model):
    """FileDataTypeResponse.

    :param file_data_type_id: The id of the file data type
    :type file_data_type_id: int
    :param file_data_type_code: The code of the file data type
    :type file_data_type_code: str
    :param file_data_type_info: The name of the file data type
    :type file_data_type_info: str
    :param supported_extensions: A list of supported extensions for this file
     data type
    :type supported_extensions: list[str]
    :param max_size_in_bytes: The maximum size, in bytes, supported for this
     file data type
    :type max_size_in_bytes: int
    """

    _attribute_map = {
        'file_data_type_id': {'key': 'fileDataTypeId', 'type': 'int'},
        'file_data_type_code': {'key': 'fileDataTypeCode', 'type': 'str'},
        'file_data_type_info': {'key': 'fileDataTypeInfo', 'type': 'str'},
        'supported_extensions': {'key': 'supportedExtensions', 'type': '[str]'},
        'max_size_in_bytes': {'key': 'maxSizeInBytes', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(FileDataTypeResponse, self).__init__(**kwargs)
        self.file_data_type_id = kwargs.get('file_data_type_id', None)
        self.file_data_type_code = kwargs.get('file_data_type_code', None)
        self.file_data_type_info = kwargs.get('file_data_type_info', None)
        self.supported_extensions = kwargs.get('supported_extensions', None)
        self.max_size_in_bytes = kwargs.get('max_size_in_bytes', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupDigestDemandRankingResponse(Model):
    """MeterGroupDigestDemandRankingResponse.

    :param high_cost:
    :type high_cost: float
    :param low_cost:
    :type low_cost: float
    :param average_cost:
    :type average_cost: float
    :param median_cost:
    :type median_cost: float
    :param high_value:
    :type high_value: float
    :param low_value:
    :type low_value: float
    :param average_value:
    :type average_value: float
    :param median_value:
    :type median_value: float
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param benchmark_unit:
    :type benchmark_unit: str
    :param benchmark_value_unit:
    :type benchmark_value_unit: str
    :param benchmark_factor_unit:
    :type benchmark_factor_unit: str
    :param results:
    :type results:
     list[~energycap.sdk.models.MeterGroupDigestDemandRankingChild]
    :param meter_group_id:
    :type meter_group_id: int
    :param meter_group_code:
    :type meter_group_code: str
    :param meter_group_info:
    :type meter_group_info: str
    :param meter_group_display:
    :type meter_group_display: str
    :param updated: The date and time the data was updated
    :type updated: datetime
    """

    _attribute_map = {
        'high_cost': {'key': 'highCost', 'type': 'float'},
        'low_cost': {'key': 'lowCost', 'type': 'float'},
        'average_cost': {'key': 'averageCost', 'type': 'float'},
        'median_cost': {'key': 'medianCost', 'type': 'float'},
        'high_value': {'key': 'highValue', 'type': 'float'},
        'low_value': {'key': 'lowValue', 'type': 'float'},
        'average_value': {'key': 'averageValue', 'type': 'float'},
        'median_value': {'key': 'medianValue', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'benchmark_unit': {'key': 'benchmarkUnit', 'type': 'str'},
        'benchmark_value_unit': {'key': 'benchmarkValueUnit', 'type': 'str'},
        'benchmark_factor_unit': {'key': 'benchmarkFactorUnit', 'type': 'str'},
        'results': {'key': 'results', 'type': '[MeterGroupDigestDemandRankingChild]'},
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'meter_group_code': {'key': 'meterGroupCode', 'type': 'str'},
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'meter_group_display': {'key': 'meterGroupDisplay', 'type': 'str'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(MeterGroupDigestDemandRankingResponse, self).__init__(**kwargs)
        self.high_cost = kwargs.get('high_cost', None)
        self.low_cost = kwargs.get('low_cost', None)
        self.average_cost = kwargs.get('average_cost', None)
        self.median_cost = kwargs.get('median_cost', None)
        self.high_value = kwargs.get('high_value', None)
        self.low_value = kwargs.get('low_value', None)
        self.average_value = kwargs.get('average_value', None)
        self.median_value = kwargs.get('median_value', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.benchmark_unit = kwargs.get('benchmark_unit', None)
        self.benchmark_value_unit = kwargs.get('benchmark_value_unit', None)
        self.benchmark_factor_unit = kwargs.get('benchmark_factor_unit', None)
        self.results = kwargs.get('results', None)
        self.meter_group_id = kwargs.get('meter_group_id', None)
        self.meter_group_code = kwargs.get('meter_group_code', None)
        self.meter_group_info = kwargs.get('meter_group_info', None)
        self.meter_group_display = kwargs.get('meter_group_display', None)
        self.updated = kwargs.get('updated', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseGHGType(Model):
    """PlaceDigestGHGYearlyResponseGHGType.

    :param ghg_type_id: GHG type identifier
    :type ghg_type_id: int
    :param ghg_type_code: GHG type code
    :type ghg_type_code: str
    :param ghg_type_info: GHG type info
    :type ghg_type_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGYearlyResponseTargetComparison
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseResults]
    """

    _attribute_map = {
        'ghg_type_id': {'key': 'ghgTypeId', 'type': 'int'},
        'ghg_type_code': {'key': 'ghgTypeCode', 'type': 'str'},
        'ghg_type_info': {'key': 'ghgTypeInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGYearlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGYearlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestGHGYearlyResponseGHGType, self).__init__(**kwargs)
        self.ghg_type_id = kwargs.get('ghg_type_id', None)
        self.ghg_type_code = kwargs.get('ghg_type_code', None)
        self.ghg_type_info = kwargs.get('ghg_type_info', None)
        self.target_comparison = kwargs.get('target_comparison', None)
        self.results = kwargs.get('results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmailProperties(Model):
    """EmailProperties.

    All required parameters must be populated in order to send to Azure.

    :param subject: Required.  <span class='property-internal'>Required</span>
    :type subject: str
    :param body:
    :type body: str
    :param recipients:  <span class='property-internal'>Cannot be Empty</span>
    :type recipients: list[str]
    """

    _validation = {
        'subject': {'required': True},
    }

    _attribute_map = {
        'subject': {'key': 'subject', 'type': 'str'},
        'body': {'key': 'body', 'type': 'str'},
        'recipients': {'key': 'recipients', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(EmailProperties, self).__init__(**kwargs)
        self.subject = kwargs.get('subject', None)
        self.body = kwargs.get('body', None)
        self.recipients = kwargs.get('recipients', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountCodeHistoryChild(Model):
    """AccountCodeHistoryChild.

    :param previous_account_code: The previous account code of this account
    :type previous_account_code: str
    :param end_date: Date that the account code was changed
    :type end_date: datetime
    """

    _attribute_map = {
        'previous_account_code': {'key': 'previousAccountCode', 'type': 'str'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, previous_account_code: str=None, end_date=None, **kwargs) -> None:
        super(AccountCodeHistoryChild, self).__init__(**kwargs)
        self.previous_account_code = previous_account_code
        self.end_date = end_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGTypeChild(Model):
    """GHGTypeChild.

    :param ghg_type_id: The identifier for the ghg type
    :type ghg_type_id: int
    :param ghg_type_code: The ghg type code
    :type ghg_type_code: str
    :param ghg_type_info: The ghg type info
    :type ghg_type_info: str
    """

    _attribute_map = {
        'ghg_type_id': {'key': 'ghgTypeId', 'type': 'int'},
        'ghg_type_code': {'key': 'ghgTypeCode', 'type': 'str'},
        'ghg_type_info': {'key': 'ghgTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, ghg_type_id: int=None, ghg_type_code: str=None, ghg_type_info: str=None, **kwargs) -> None:
        super(GHGTypeChild, self).__init__(**kwargs)
        self.ghg_type_id = ghg_type_id
        self.ghg_type_code = ghg_type_code
        self.ghg_type_info = ghg_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillCalendarizedHistory(Model):
    """BillCalendarizedHistory.

    :param billing_period: Billing Period (YYYYMM)
    :type billing_period: int
    :param month: Calendarized Month
    :type month: int
    :param year: Calendarized Year
    :type year: int
    :param current: Is this period within the last year
    :type current: bool
    :param account_id: Account ID
    :type account_id: int
    :param meter_id: Meter ID
    :type meter_id: int
    :param use_per_day: Use per day (native)
    :type use_per_day: float
    :param use_unit: Use unit name (native)
    :type use_unit: str
    :param cost_per_day: Cost per day
    :type cost_per_day: float
    :param unit_cost: Unit cost
    :type unit_cost: float
    :param cost_unit: Cost unit name
    :type cost_unit: str
    :param demand: Demand (native)
    :type demand: float
    :param demand_unit: Demand unit name (native)
    :type demand_unit: str
    :param actual_demand: Actual Demand (native)
    :type actual_demand: float
    :param actual_demand_unit: Actual Demand unit name (native)
    :type actual_demand_unit: str
    :param billed_demand: Billed Demand (native)
    :type billed_demand: float
    :param billed_demand_unit: Billed Demand unit name (native)
    :type billed_demand_unit: str
    """

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'month': {'key': 'month', 'type': 'int'},
        'year': {'key': 'year', 'type': 'int'},
        'current': {'key': 'current', 'type': 'bool'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'use_per_day': {'key': 'usePerDay', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'str'},
        'cost_per_day': {'key': 'costPerDay', 'type': 'float'},
        'unit_cost': {'key': 'unitCost', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'str'},
        'demand': {'key': 'demand', 'type': 'float'},
        'demand_unit': {'key': 'demandUnit', 'type': 'str'},
        'actual_demand': {'key': 'actualDemand', 'type': 'float'},
        'actual_demand_unit': {'key': 'actualDemandUnit', 'type': 'str'},
        'billed_demand': {'key': 'billedDemand', 'type': 'float'},
        'billed_demand_unit': {'key': 'billedDemandUnit', 'type': 'str'},
    }

    def __init__(self, *, billing_period: int=None, month: int=None, year: int=None, current: bool=None, account_id: int=None, meter_id: int=None, use_per_day: float=None, use_unit: str=None, cost_per_day: float=None, unit_cost: float=None, cost_unit: str=None, demand: float=None, demand_unit: str=None, actual_demand: float=None, actual_demand_unit: str=None, billed_demand: float=None, billed_demand_unit: str=None, **kwargs) -> None:
        super(BillCalendarizedHistory, self).__init__(**kwargs)
        self.billing_period = billing_period
        self.month = month
        self.year = year
        self.current = current
        self.account_id = account_id
        self.meter_id = meter_id
        self.use_per_day = use_per_day
        self.use_unit = use_unit
        self.cost_per_day = cost_per_day
        self.unit_cost = unit_cost
        self.cost_unit = cost_unit
        self.demand = demand
        self.demand_unit = demand_unit
        self.actual_demand = actual_demand
        self.actual_demand_unit = actual_demand_unit
        self.billed_demand = billed_demand
        self.billed_demand_unit = billed_demand_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListColumnEdit(Model):
    """ListColumnEdit.

    All required parameters must be populated in order to send to Azure.

    :param field_id: Required. Column/Filter Identifier <span
     class='property-internal'>Required</span>
    :type field_id: int
    :param width: Required. Width of the column <span
     class='property-internal'>Required</span>
    :type width: int
    :param display_order: Required. Order of the column <span
     class='property-internal'>Required</span>
    :type display_order: int
    :param sort_order: Required. Sort order for the column <span
     class='property-internal'>Required</span>
    :type sort_order: int
    :param sort_direction: Required. Sort direction <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of asc, desc </span>
    :type sort_direction: str
    :param visible: Required. Is the column visible? <span
     class='property-internal'>Required</span>
    :type visible: bool
    """

    _validation = {
        'field_id': {'required': True},
        'width': {'required': True},
        'display_order': {'required': True},
        'sort_order': {'required': True},
        'sort_direction': {'required': True},
        'visible': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'sort_order': {'key': 'sortOrder', 'type': 'int'},
        'sort_direction': {'key': 'sortDirection', 'type': 'str'},
        'visible': {'key': 'visible', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ListColumnEdit, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.width = kwargs.get('width', None)
        self.display_order = kwargs.get('display_order', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.sort_direction = kwargs.get('sort_direction', None)
        self.visible = kwargs.get('visible', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationResponse(Model):
    """NotificationResponse.

    :param message_preview: The notification message with any html tags
     stripped out
    :type message_preview: str
    :param notification_id: The id of the notification
    :type notification_id: long
    :param read: True if the notification has been read
    :type read: bool
    :param archived: True if the notification has been archived
    :type archived: bool
    :param subject: Subject of the notification
    :type subject: str
    :param created_date: The date and time the notification was generated
    :type created_date: datetime
    :param notification_type:
    :type notification_type: ~energycap.sdk.models.NotificationType
    """

    _attribute_map = {
        'message_preview': {'key': 'messagePreview', 'type': 'str'},
        'notification_id': {'key': 'notificationId', 'type': 'long'},
        'read': {'key': 'read', 'type': 'bool'},
        'archived': {'key': 'archived', 'type': 'bool'},
        'subject': {'key': 'subject', 'type': 'str'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'notification_type': {'key': 'notificationType', 'type': 'NotificationType'},
    }

    def __init__(self, *, message_preview: str=None, notification_id: int=None, read: bool=None, archived: bool=None, subject: str=None, created_date=None, notification_type=None, **kwargs) -> None:
        super(NotificationResponse, self).__init__(**kwargs)
        self.message_preview = message_preview
        self.notification_id = notification_id
        self.read = read
        self.archived = archived
        self.subject = subject
        self.created_date = created_date
        self.notification_type = notification_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WorkflowDisplaySetting(Model):
    """WorkflowDisplaySetting.

    :param show_unapproved_list: Indicates whether or not to show the
     Unapproved bill list in Bill Processing
    :type show_unapproved_list: bool
    :param show_ap_export_list: Indicates whether or not to show the Waiting
     for Export to AP bill list in Bill Processing
    :type show_ap_export_list: bool
    :param show_gl_export_list: Indicates whether or not to show the Waiting
     for Export to GL bill list in Bill Processing
    :type show_gl_export_list: bool
    :param show_export_hold_list: Indicates whether or not to show the Held
     from Export bill list in Bill Processing
    :type show_export_hold_list: bool
    """

    _attribute_map = {
        'show_unapproved_list': {'key': 'showUnapprovedList', 'type': 'bool'},
        'show_ap_export_list': {'key': 'showAPExportList', 'type': 'bool'},
        'show_gl_export_list': {'key': 'showGLExportList', 'type': 'bool'},
        'show_export_hold_list': {'key': 'showExportHoldList', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(WorkflowDisplaySetting, self).__init__(**kwargs)
        self.show_unapproved_list = kwargs.get('show_unapproved_list', None)
        self.show_ap_export_list = kwargs.get('show_ap_export_list', None)
        self.show_gl_export_list = kwargs.get('show_gl_export_list', None)
        self.show_export_hold_list = kwargs.get('show_export_hold_list', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskResponse(Model):
    """TaskResponse.

    :param has_attachments:
    :type has_attachments: bool
    :param task_id:
    :type task_id: int
    :param task_gu_id: The task guid
    :type task_gu_id: str
    :param task_type:
    :type task_type: ~energycap.sdk.models.TaskType
    :param begin_date: The date and time the task began
    :type begin_date: datetime
    :param end_date: The date and time the task finished. If the task is not
     finished, endDate will have no value
    :type end_date: datetime
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param message: The task's message
    :type message: str
    :param output: The task's output. For certain task types, this field could
     be sizable
    :type output: object
    :param settings: The task's settings
    :type settings: object
    :param status: The task's status
    :type status: str
    :param task_note: User provided note/comment for this Task
    :type task_note: str
    :param analyzing_count: Count of bills that are in the analyzing state,
     used by bill import tasks only
    :type analyzing_count: int
    :param unresolved_flag_count: The count of bills with unresolved flags on
     this task, used by bill import tasks only
    :type unresolved_flag_count: int
    :param current_success_count: The count of successful bills that still
     exist (i.e. have not been deleted), used by bill import tasks only
    :type current_success_count: int
    """

    _attribute_map = {
        'has_attachments': {'key': 'hasAttachments', 'type': 'bool'},
        'task_id': {'key': 'taskId', 'type': 'int'},
        'task_gu_id': {'key': 'taskGUId', 'type': 'str'},
        'task_type': {'key': 'taskType', 'type': 'TaskType'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'message': {'key': 'message', 'type': 'str'},
        'output': {'key': 'output', 'type': 'object'},
        'settings': {'key': 'settings', 'type': 'object'},
        'status': {'key': 'status', 'type': 'str'},
        'task_note': {'key': 'taskNote', 'type': 'str'},
        'analyzing_count': {'key': 'analyzingCount', 'type': 'int'},
        'unresolved_flag_count': {'key': 'unresolvedFlagCount', 'type': 'int'},
        'current_success_count': {'key': 'currentSuccessCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(TaskResponse, self).__init__(**kwargs)
        self.has_attachments = kwargs.get('has_attachments', None)
        self.task_id = kwargs.get('task_id', None)
        self.task_gu_id = kwargs.get('task_gu_id', None)
        self.task_type = kwargs.get('task_type', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.user = kwargs.get('user', None)
        self.message = kwargs.get('message', None)
        self.output = kwargs.get('output', None)
        self.settings = kwargs.get('settings', None)
        self.status = kwargs.get('status', None)
        self.task_note = kwargs.get('task_note', None)
        self.analyzing_count = kwargs.get('analyzing_count', None)
        self.unresolved_flag_count = kwargs.get('unresolved_flag_count', None)
        self.current_success_count = kwargs.get('current_success_count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardEdit(Model):
    """DashboardEdit.

    All required parameters must be populated in order to send to Azure.

    :param dashboard_info: Required. The Dashboard Title <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type dashboard_info: str
    :param description: The dashboard description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
     <span class='property-internal'>Required (defined)</span>
    :type description: str
    :param type: The dashboard type <span class='property-internal'>One of
     User, Map </span> <span class='property-internal'>Required
     (defined)</span>
    :type type: str
    :param public: Required. Flag to indicate if the dashboard is public <span
     class='property-internal'>Required</span>
    :type public: bool
    """

    _validation = {
        'dashboard_info': {'required': True, 'max_length': 255, 'min_length': 0},
        'description': {'max_length': 255, 'min_length': 0},
        'public': {'required': True},
    }

    _attribute_map = {
        'dashboard_info': {'key': 'dashboardInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'public': {'key': 'public', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DashboardEdit, self).__init__(**kwargs)
        self.dashboard_info = kwargs.get('dashboard_info', None)
        self.description = kwargs.get('description', None)
        self.type = kwargs.get('type', None)
        self.public = kwargs.get('public', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BuildingAndMeterGroupsClassPermission(Model):
    """BuildingAndMeterGroupsClassPermission.

    :param create:
    :type create: bool
    :param edit:
    :type edit: bool
    :param delete:
    :type delete: bool
    """

    _attribute_map = {
        'create': {'key': 'create', 'type': 'bool'},
        'edit': {'key': 'edit', 'type': 'bool'},
        'delete': {'key': 'delete', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BuildingAndMeterGroupsClassPermission, self).__init__(**kwargs)
        self.create = kwargs.get('create', None)
        self.edit = kwargs.get('edit', None)
        self.delete = kwargs.get('delete', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationSettingResponse(Model):
    """NotificationSettingResponse.

    :param notification_type:
    :type notification_type: ~energycap.sdk.models.NotificationType
    :param configured_notification_option: The currently configured
     notification option
    :type configured_notification_option: str
    :param available_notification_options: All possible notification options
     for this setting
    :type available_notification_options: list[str]
    """

    _attribute_map = {
        'notification_type': {'key': 'notificationType', 'type': 'NotificationType'},
        'configured_notification_option': {'key': 'configuredNotificationOption', 'type': 'str'},
        'available_notification_options': {'key': 'availableNotificationOptions', 'type': '[str]'},
    }

    def __init__(self, *, notification_type=None, configured_notification_option: str=None, available_notification_options=None, **kwargs) -> None:
        super(NotificationSettingResponse, self).__init__(**kwargs)
        self.notification_type = notification_type
        self.configured_notification_option = configured_notification_option
        self.available_notification_options = available_notification_options



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationChild(Model):
    """WeatherStationChild.

    :param station_id: Weather Station Id
    :type station_id: int
    :param station_code: Weather Station Code
    :type station_code: str
    :param station_info: Weather Station Name
    :type station_info: str
    :param city: City the weather station is located
    :type city: str
    :param state: State the weather station is located
    :type state: str
    :param country: Country the weather station is located
    :type country: str
    """

    _attribute_map = {
        'station_id': {'key': 'stationId', 'type': 'int'},
        'station_code': {'key': 'stationCode', 'type': 'str'},
        'station_info': {'key': 'stationInfo', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WeatherStationChild, self).__init__(**kwargs)
        self.station_id = kwargs.get('station_id', None)
        self.station_code = kwargs.get('station_code', None)
        self.station_info = kwargs.get('station_info', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessRelease(Model):
    """DataAccessRelease.

    :param data_access_release_id: Data Access Release Identifier
    :type data_access_release_id: int
    :param meta_data:
    :type meta_data: ~energycap.sdk.models.DataAccessReleaseMetaData
    :param release_form: File name of the uploaded release form
     This is only saved on a manual data release request
     Null when request was completed by email
    :type release_form: str
    :param submitted_date: Date and time the data release request was
     submitted
    :type submitted_date: datetime
    :param submitted_by: Email address of the person who completed the request
    :type submitted_by: str
    """

    _attribute_map = {
        'data_access_release_id': {'key': 'dataAccessReleaseId', 'type': 'int'},
        'meta_data': {'key': 'metaData', 'type': 'DataAccessReleaseMetaData'},
        'release_form': {'key': 'releaseForm', 'type': 'str'},
        'submitted_date': {'key': 'submittedDate', 'type': 'iso-8601'},
        'submitted_by': {'key': 'submittedBy', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataAccessRelease, self).__init__(**kwargs)
        self.data_access_release_id = kwargs.get('data_access_release_id', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.release_form = kwargs.get('release_form', None)
        self.submitted_date = kwargs.get('submitted_date', None)
        self.submitted_by = kwargs.get('submitted_by', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseResults(Model):
    """PlaceDigestGHGYearlyResponseResults.

    :param year: year
    :type year: str
    :param equivalent_co2_emissions: Equivalent CO2 emissions
    :type equivalent_co2_emissions: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'equivalent_co2_emissions': {'key': 'equivalentCO2Emissions', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestGHGYearlyResponseResults, self).__init__(**kwargs)
        self.year = kwargs.get('year', None)
        self.equivalent_co2_emissions = kwargs.get('equivalent_co2_emissions', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GLSubCodeChild(Model):
    """GLSubCodeChild.

    :param sub_code_index: Index of this subcode (01-20)
    :type sub_code_index: str
    :param sub_code_name: Name for this SubCode
    :type sub_code_name: str
    :param value: The value assigned to the subcode
    :type value: str
    """

    _attribute_map = {
        'sub_code_index': {'key': 'subCodeIndex', 'type': 'str'},
        'sub_code_name': {'key': 'subCodeName', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, sub_code_index: str=None, sub_code_name: str=None, value: str=None, **kwargs) -> None:
        super(GLSubCodeChild, self).__init__(**kwargs)
        self.sub_code_index = sub_code_index
        self.sub_code_name = sub_code_name
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Permissions(Model):
    """Permissions.

    :param license_feature_accounting_export:
    :type license_feature_accounting_export:
     ~energycap.sdk.models.LicenseFeatureAccountingExport
    :param license_feature_accrual_bills:
    :type license_feature_accrual_bills:
     ~energycap.sdk.models.LicenseFeatureAccrualBills
    :param license_feature_chargebacks:
    :type license_feature_chargebacks:
     ~energycap.sdk.models.LicenseFeatureChargebacks
    :param license_feature_cost_avoidance:
    :type license_feature_cost_avoidance:
     ~energycap.sdk.models.LicenseFeatureCostAvoidance
    :param license_feature_interval_data_analysis:
    :type license_feature_interval_data_analysis:
     ~energycap.sdk.models.LicenseFeatureIntervalDataAnalysis
    :param license_feature_report_designer:
    :type license_feature_report_designer:
     ~energycap.sdk.models.LicenseFeatureReportDesigner
    :param license_feature_custom_benchmarks:
    :type license_feature_custom_benchmarks:
     ~energycap.sdk.models.LicenseFeatureCustomBenchmarks
    :param license_feature_report_distribution:
    :type license_feature_report_distribution:
     ~energycap.sdk.models.LicenseFeatureReportDistribution
    :param accounting_settings:
    :type accounting_settings: ~energycap.sdk.models.AccountingSettings
    :param accounts:
    :type accounts: ~energycap.sdk.models.Accounts
    :param accounts_module:
    :type accounts_module: ~energycap.sdk.models.AccountsModule
    :param accrual_settings:
    :type accrual_settings: ~energycap.sdk.models.AccrualSettings
    :param cost_centers:
    :type cost_centers: ~energycap.sdk.models.CostCenters
    :param move_accounts_between_vendors:
    :type move_accounts_between_vendors:
     ~energycap.sdk.models.MoveAccountsBetweenVendors
    :param application_settings:
    :type application_settings: ~energycap.sdk.models.ApplicationSettings
    :param approve_bills:
    :type approve_bills: ~energycap.sdk.models.ApproveBills
    :param bill_workflow_settings:
    :type bill_workflow_settings: ~energycap.sdk.models.BillWorkflowSettings
    :param bills_and_batches:
    :type bills_and_batches: ~energycap.sdk.models.BillsAndBatches
    :param export_bills:
    :type export_bills: ~energycap.sdk.models.ExportBills
    :param export_hold:
    :type export_hold: ~energycap.sdk.models.ExportHold
    :param move_existing_bills:
    :type move_existing_bills: ~energycap.sdk.models.MoveExistingBills
    :param shared_bill_lists:
    :type shared_bill_lists: ~energycap.sdk.models.SharedBillLists
    :param unit_system_settings:
    :type unit_system_settings: ~energycap.sdk.models.UnitSystemSettings
    :param update_approved_bills:
    :type update_approved_bills: ~energycap.sdk.models.UpdateApprovedBills
    :param update_units_on_existing_bills:
    :type update_units_on_existing_bills:
     ~energycap.sdk.models.UpdateUnitsOnExistingBills
    :param budgets_and_budget_versions:
    :type budgets_and_budget_versions:
     ~energycap.sdk.models.BudgetsAndBudgetVersions
    :param chargebacks_module:
    :type chargebacks_module: ~energycap.sdk.models.ChargebacksModule
    :param chargebacks:
    :type chargebacks: ~energycap.sdk.models.Chargebacks
    :param chargeback_reversals:
    :type chargeback_reversals: ~energycap.sdk.models.ChargebackReversals
    :param meter_savings_settings:
    :type meter_savings_settings: ~energycap.sdk.models.MeterSavingsSettings
    :param savings_adjustments:
    :type savings_adjustments: ~energycap.sdk.models.SavingsAdjustments
    :param manually_adjust_savings:
    :type manually_adjust_savings: ~energycap.sdk.models.ManuallyAdjustSavings
    :param savings_engine:
    :type savings_engine: ~energycap.sdk.models.SavingsEngine
    :param baseline_engine:
    :type baseline_engine: ~energycap.sdk.models.BaselineEngine
    :param global_cost_avoidance_settings:
    :type global_cost_avoidance_settings:
     ~energycap.sdk.models.GlobalCostAvoidanceSettings
    :param dashboard_and_maps_module:
    :type dashboard_and_maps_module:
     ~energycap.sdk.models.DashboardAndMapsModule
    :param dashboard_administrator:
    :type dashboard_administrator:
     ~energycap.sdk.models.DashboardAdministrator
    :param public_dashboards_or_maps:
    :type public_dashboards_or_maps:
     ~energycap.sdk.models.PublicDashboardsOrMaps
    :param shared_dashboards_or_maps:
    :type shared_dashboards_or_maps:
     ~energycap.sdk.models.SharedDashboardsOrMaps
    :param buildings_and_meters_module:
    :type buildings_and_meters_module:
     ~energycap.sdk.models.BuildingsAndMetersModule
    :param groups_and_benchmarks_module:
    :type groups_and_benchmarks_module:
     ~energycap.sdk.models.GroupsAndBenchmarksModule
    :param building_and_meter_groups:
    :type building_and_meter_groups:
     ~energycap.sdk.models.BuildingAndMeterGroups
    :param buildings_and_organizations:
    :type buildings_and_organizations:
     ~energycap.sdk.models.BuildingsAndOrganizations
    :param interval_data:
    :type interval_data: ~energycap.sdk.models.IntervalData
    :param interval_data_analysis:
    :type interval_data_analysis: ~energycap.sdk.models.IntervalDataAnalysis
    :param energystar_submissions:
    :type energystar_submissions: ~energycap.sdk.models.ENERGYSTARSubmissions
    :param facility_projects:
    :type facility_projects: ~energycap.sdk.models.FacilityProjects
    :param greenhouse_gas_administrator:
    :type greenhouse_gas_administrator:
     ~energycap.sdk.models.GreenhouseGasAdministrator
    :param interval_data_rollup:
    :type interval_data_rollup: ~energycap.sdk.models.IntervalDataRollup
    :param meters:
    :type meters: ~energycap.sdk.models.Meters
    :param normalization_settings:
    :type normalization_settings: ~energycap.sdk.models.NormalizationSettings
    :param weather_settings:
    :type weather_settings: ~energycap.sdk.models.WeatherSettings
    :param reports_module:
    :type reports_module: ~energycap.sdk.models.ReportsModule
    :param distributed_reports_settings:
    :type distributed_reports_settings:
     ~energycap.sdk.models.DistributedReportsSettings
    :param report_administrator:
    :type report_administrator: ~energycap.sdk.models.ReportAdministrator
    :param report_groups:
    :type report_groups: ~energycap.sdk.models.ReportGroups
    :param shared_reports:
    :type shared_reports: ~energycap.sdk.models.SharedReports
    :param reset_user_passwords:
    :type reset_user_passwords: ~energycap.sdk.models.ResetUserPasswords
    :param users_and_roles:
    :type users_and_roles: ~energycap.sdk.models.UsersAndRoles
    :param vendors_and_rates_module:
    :type vendors_and_rates_module:
     ~energycap.sdk.models.VendorsAndRatesModule
    :param rate_schedules:
    :type rate_schedules: ~energycap.sdk.models.RateSchedules
    :param vendors:
    :type vendors: ~energycap.sdk.models.Vendors
    :param flagged_items:
    :type flagged_items: ~energycap.sdk.models.FlaggedItems
    :param bill_list_administrator:
    :type bill_list_administrator: ~energycap.sdk.models.BillListAdministrator
    :param all_installed_reports:
    :type all_installed_reports: ~energycap.sdk.models.AllInstalledReports
    :param send_notifications:
    :type send_notifications: ~energycap.sdk.models.SendNotifications
    """

    _attribute_map = {
        'license_feature_accounting_export': {'key': 'licenseFeatureAccountingExport', 'type': 'LicenseFeatureAccountingExport'},
        'license_feature_accrual_bills': {'key': 'licenseFeatureAccrualBills', 'type': 'LicenseFeatureAccrualBills'},
        'license_feature_chargebacks': {'key': 'licenseFeatureChargebacks', 'type': 'LicenseFeatureChargebacks'},
        'license_feature_cost_avoidance': {'key': 'licenseFeatureCostAvoidance', 'type': 'LicenseFeatureCostAvoidance'},
        'license_feature_interval_data_analysis': {'key': 'licenseFeatureIntervalDataAnalysis', 'type': 'LicenseFeatureIntervalDataAnalysis'},
        'license_feature_report_designer': {'key': 'licenseFeatureReportDesigner', 'type': 'LicenseFeatureReportDesigner'},
        'license_feature_custom_benchmarks': {'key': 'licenseFeatureCustomBenchmarks', 'type': 'LicenseFeatureCustomBenchmarks'},
        'license_feature_report_distribution': {'key': 'licenseFeatureReportDistribution', 'type': 'LicenseFeatureReportDistribution'},
        'accounting_settings': {'key': 'accountingSettings', 'type': 'AccountingSettings'},
        'accounts': {'key': 'accounts', 'type': 'Accounts'},
        'accounts_module': {'key': 'accountsModule', 'type': 'AccountsModule'},
        'accrual_settings': {'key': 'accrualSettings', 'type': 'AccrualSettings'},
        'cost_centers': {'key': 'costCenters', 'type': 'CostCenters'},
        'move_accounts_between_vendors': {'key': 'moveAccountsBetweenVendors', 'type': 'MoveAccountsBetweenVendors'},
        'application_settings': {'key': 'applicationSettings', 'type': 'ApplicationSettings'},
        'approve_bills': {'key': 'approveBills', 'type': 'ApproveBills'},
        'bill_workflow_settings': {'key': 'billWorkflowSettings', 'type': 'BillWorkflowSettings'},
        'bills_and_batches': {'key': 'billsAndBatches', 'type': 'BillsAndBatches'},
        'export_bills': {'key': 'exportBills', 'type': 'ExportBills'},
        'export_hold': {'key': 'exportHold', 'type': 'ExportHold'},
        'move_existing_bills': {'key': 'moveExistingBills', 'type': 'MoveExistingBills'},
        'shared_bill_lists': {'key': 'sharedBillLists', 'type': 'SharedBillLists'},
        'unit_system_settings': {'key': 'unitSystemSettings', 'type': 'UnitSystemSettings'},
        'update_approved_bills': {'key': 'updateApprovedBills', 'type': 'UpdateApprovedBills'},
        'update_units_on_existing_bills': {'key': 'updateUnitsOnExistingBills', 'type': 'UpdateUnitsOnExistingBills'},
        'budgets_and_budget_versions': {'key': 'budgetsAndBudgetVersions', 'type': 'BudgetsAndBudgetVersions'},
        'chargebacks_module': {'key': 'chargebacksModule', 'type': 'ChargebacksModule'},
        'chargebacks': {'key': 'chargebacks', 'type': 'Chargebacks'},
        'chargeback_reversals': {'key': 'chargebackReversals', 'type': 'ChargebackReversals'},
        'meter_savings_settings': {'key': 'meterSavingsSettings', 'type': 'MeterSavingsSettings'},
        'savings_adjustments': {'key': 'savingsAdjustments', 'type': 'SavingsAdjustments'},
        'manually_adjust_savings': {'key': 'manuallyAdjustSavings', 'type': 'ManuallyAdjustSavings'},
        'savings_engine': {'key': 'savingsEngine', 'type': 'SavingsEngine'},
        'baseline_engine': {'key': 'baselineEngine', 'type': 'BaselineEngine'},
        'global_cost_avoidance_settings': {'key': 'globalCostAvoidanceSettings', 'type': 'GlobalCostAvoidanceSettings'},
        'dashboard_and_maps_module': {'key': 'dashboardAndMapsModule', 'type': 'DashboardAndMapsModule'},
        'dashboard_administrator': {'key': 'dashboardAdministrator', 'type': 'DashboardAdministrator'},
        'public_dashboards_or_maps': {'key': 'publicDashboardsOrMaps', 'type': 'PublicDashboardsOrMaps'},
        'shared_dashboards_or_maps': {'key': 'sharedDashboardsOrMaps', 'type': 'SharedDashboardsOrMaps'},
        'buildings_and_meters_module': {'key': 'buildingsAndMetersModule', 'type': 'BuildingsAndMetersModule'},
        'groups_and_benchmarks_module': {'key': 'groupsAndBenchmarksModule', 'type': 'GroupsAndBenchmarksModule'},
        'building_and_meter_groups': {'key': 'buildingAndMeterGroups', 'type': 'BuildingAndMeterGroups'},
        'buildings_and_organizations': {'key': 'buildingsAndOrganizations', 'type': 'BuildingsAndOrganizations'},
        'interval_data': {'key': 'intervalData', 'type': 'IntervalData'},
        'interval_data_analysis': {'key': 'intervalDataAnalysis', 'type': 'IntervalDataAnalysis'},
        'energystar_submissions': {'key': 'energystarSubmissions', 'type': 'ENERGYSTARSubmissions'},
        'facility_projects': {'key': 'facilityProjects', 'type': 'FacilityProjects'},
        'greenhouse_gas_administrator': {'key': 'greenhouseGasAdministrator', 'type': 'GreenhouseGasAdministrator'},
        'interval_data_rollup': {'key': 'intervalDataRollup', 'type': 'IntervalDataRollup'},
        'meters': {'key': 'meters', 'type': 'Meters'},
        'normalization_settings': {'key': 'normalizationSettings', 'type': 'NormalizationSettings'},
        'weather_settings': {'key': 'weatherSettings', 'type': 'WeatherSettings'},
        'reports_module': {'key': 'reportsModule', 'type': 'ReportsModule'},
        'distributed_reports_settings': {'key': 'distributedReportsSettings', 'type': 'DistributedReportsSettings'},
        'report_administrator': {'key': 'reportAdministrator', 'type': 'ReportAdministrator'},
        'report_groups': {'key': 'reportGroups', 'type': 'ReportGroups'},
        'shared_reports': {'key': 'sharedReports', 'type': 'SharedReports'},
        'reset_user_passwords': {'key': 'resetUserPasswords', 'type': 'ResetUserPasswords'},
        'users_and_roles': {'key': 'usersAndRoles', 'type': 'UsersAndRoles'},
        'vendors_and_rates_module': {'key': 'vendorsAndRatesModule', 'type': 'VendorsAndRatesModule'},
        'rate_schedules': {'key': 'rateSchedules', 'type': 'RateSchedules'},
        'vendors': {'key': 'vendors', 'type': 'Vendors'},
        'flagged_items': {'key': 'flaggedItems', 'type': 'FlaggedItems'},
        'bill_list_administrator': {'key': 'billListAdministrator', 'type': 'BillListAdministrator'},
        'all_installed_reports': {'key': 'allInstalledReports', 'type': 'AllInstalledReports'},
        'send_notifications': {'key': 'sendNotifications', 'type': 'SendNotifications'},
    }

    def __init__(self, *, license_feature_accounting_export=None, license_feature_accrual_bills=None, license_feature_chargebacks=None, license_feature_cost_avoidance=None, license_feature_interval_data_analysis=None, license_feature_report_designer=None, license_feature_custom_benchmarks=None, license_feature_report_distribution=None, accounting_settings=None, accounts=None, accounts_module=None, accrual_settings=None, cost_centers=None, move_accounts_between_vendors=None, application_settings=None, approve_bills=None, bill_workflow_settings=None, bills_and_batches=None, export_bills=None, export_hold=None, move_existing_bills=None, shared_bill_lists=None, unit_system_settings=None, update_approved_bills=None, update_units_on_existing_bills=None, budgets_and_budget_versions=None, chargebacks_module=None, chargebacks=None, chargeback_reversals=None, meter_savings_settings=None, savings_adjustments=None, manually_adjust_savings=None, savings_engine=None, baseline_engine=None, global_cost_avoidance_settings=None, dashboard_and_maps_module=None, dashboard_administrator=None, public_dashboards_or_maps=None, shared_dashboards_or_maps=None, buildings_and_meters_module=None, groups_and_benchmarks_module=None, building_and_meter_groups=None, buildings_and_organizations=None, interval_data=None, interval_data_analysis=None, energystar_submissions=None, facility_projects=None, greenhouse_gas_administrator=None, interval_data_rollup=None, meters=None, normalization_settings=None, weather_settings=None, reports_module=None, distributed_reports_settings=None, report_administrator=None, report_groups=None, shared_reports=None, reset_user_passwords=None, users_and_roles=None, vendors_and_rates_module=None, rate_schedules=None, vendors=None, flagged_items=None, bill_list_administrator=None, all_installed_reports=None, send_notifications=None, **kwargs) -> None:
        super(Permissions, self).__init__(**kwargs)
        self.license_feature_accounting_export = license_feature_accounting_export
        self.license_feature_accrual_bills = license_feature_accrual_bills
        self.license_feature_chargebacks = license_feature_chargebacks
        self.license_feature_cost_avoidance = license_feature_cost_avoidance
        self.license_feature_interval_data_analysis = license_feature_interval_data_analysis
        self.license_feature_report_designer = license_feature_report_designer
        self.license_feature_custom_benchmarks = license_feature_custom_benchmarks
        self.license_feature_report_distribution = license_feature_report_distribution
        self.accounting_settings = accounting_settings
        self.accounts = accounts
        self.accounts_module = accounts_module
        self.accrual_settings = accrual_settings
        self.cost_centers = cost_centers
        self.move_accounts_between_vendors = move_accounts_between_vendors
        self.application_settings = application_settings
        self.approve_bills = approve_bills
        self.bill_workflow_settings = bill_workflow_settings
        self.bills_and_batches = bills_and_batches
        self.export_bills = export_bills
        self.export_hold = export_hold
        self.move_existing_bills = move_existing_bills
        self.shared_bill_lists = shared_bill_lists
        self.unit_system_settings = unit_system_settings
        self.update_approved_bills = update_approved_bills
        self.update_units_on_existing_bills = update_units_on_existing_bills
        self.budgets_and_budget_versions = budgets_and_budget_versions
        self.chargebacks_module = chargebacks_module
        self.chargebacks = chargebacks
        self.chargeback_reversals = chargeback_reversals
        self.meter_savings_settings = meter_savings_settings
        self.savings_adjustments = savings_adjustments
        self.manually_adjust_savings = manually_adjust_savings
        self.savings_engine = savings_engine
        self.baseline_engine = baseline_engine
        self.global_cost_avoidance_settings = global_cost_avoidance_settings
        self.dashboard_and_maps_module = dashboard_and_maps_module
        self.dashboard_administrator = dashboard_administrator
        self.public_dashboards_or_maps = public_dashboards_or_maps
        self.shared_dashboards_or_maps = shared_dashboards_or_maps
        self.buildings_and_meters_module = buildings_and_meters_module
        self.groups_and_benchmarks_module = groups_and_benchmarks_module
        self.building_and_meter_groups = building_and_meter_groups
        self.buildings_and_organizations = buildings_and_organizations
        self.interval_data = interval_data
        self.interval_data_analysis = interval_data_analysis
        self.energystar_submissions = energystar_submissions
        self.facility_projects = facility_projects
        self.greenhouse_gas_administrator = greenhouse_gas_administrator
        self.interval_data_rollup = interval_data_rollup
        self.meters = meters
        self.normalization_settings = normalization_settings
        self.weather_settings = weather_settings
        self.reports_module = reports_module
        self.distributed_reports_settings = distributed_reports_settings
        self.report_administrator = report_administrator
        self.report_groups = report_groups
        self.shared_reports = shared_reports
        self.reset_user_passwords = reset_user_passwords
        self.users_and_roles = users_and_roles
        self.vendors_and_rates_module = vendors_and_rates_module
        self.rate_schedules = rate_schedules
        self.vendors = vendors
        self.flagged_items = flagged_items
        self.bill_list_administrator = bill_list_administrator
        self.all_installed_reports = all_installed_reports
        self.send_notifications = send_notifications



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchResponse(Model):
    """BatchResponse.

    :param batch_id: The batch identifier
    :type batch_id: int
    :param batch_code: The batch code
    :type batch_code: str
    :param is_open: Is the batch open
    :type is_open: bool
    :param start_date: The date when the batch was created
    :type start_date: datetime
    :param end_date: The date when the batch was closed
    :type end_date: datetime
    :param bill_count: The number of bills in this batch
    :type bill_count: int
    :param running_total: The cost of  all bills in this batch
    :type running_total: float
    :param statement_date: Statement date batch setting
    :type statement_date: str
    :param due_date: Due date batch setting
    :type due_date: str
    :param next_reading: Next reading date batch setting
    :type next_reading: str
    :param control_code: Control code batch setting
    :type control_code: str
    :param invoice_number: Invoice number batch setting
    :type invoice_number: str
    :param account_period_name: Account period name batch setting
    :type account_period_name: str
    :param account_period_number: Account period number batch setting
    :type account_period_number: int
    :param account_period_year: Account period year batch setting
    :type account_period_year: int
    :param note: Note/comment for the batch
    :type note: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param flag_count: Number of unresolved flags on bills contained in this
     batch
    :type flag_count: int
    :param analyzing_count: Number of bills contained in this batch that are
     currently being analyzed
    :type analyzing_count: int
    """

    _attribute_map = {
        'batch_id': {'key': 'batchId', 'type': 'int'},
        'batch_code': {'key': 'batchCode', 'type': 'str'},
        'is_open': {'key': 'isOpen', 'type': 'bool'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'bill_count': {'key': 'billCount', 'type': 'int'},
        'running_total': {'key': 'runningTotal', 'type': 'float'},
        'statement_date': {'key': 'statementDate', 'type': 'str'},
        'due_date': {'key': 'dueDate', 'type': 'str'},
        'next_reading': {'key': 'nextReading', 'type': 'str'},
        'control_code': {'key': 'controlCode', 'type': 'str'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'str'},
        'account_period_name': {'key': 'accountPeriodName', 'type': 'str'},
        'account_period_number': {'key': 'accountPeriodNumber', 'type': 'int'},
        'account_period_year': {'key': 'accountPeriodYear', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'flag_count': {'key': 'flagCount', 'type': 'int'},
        'analyzing_count': {'key': 'analyzingCount', 'type': 'int'},
    }

    def __init__(self, *, batch_id: int=None, batch_code: str=None, is_open: bool=None, start_date=None, end_date=None, bill_count: int=None, running_total: float=None, statement_date: str=None, due_date: str=None, next_reading: str=None, control_code: str=None, invoice_number: str=None, account_period_name: str=None, account_period_number: int=None, account_period_year: int=None, note: str=None, created_by=None, flag_count: int=None, analyzing_count: int=None, **kwargs) -> None:
        super(BatchResponse, self).__init__(**kwargs)
        self.batch_id = batch_id
        self.batch_code = batch_code
        self.is_open = is_open
        self.start_date = start_date
        self.end_date = end_date
        self.bill_count = bill_count
        self.running_total = running_total
        self.statement_date = statement_date
        self.due_date = due_date
        self.next_reading = next_reading
        self.control_code = control_code
        self.invoice_number = invoice_number
        self.account_period_name = account_period_name
        self.account_period_number = account_period_number
        self.account_period_year = account_period_year
        self.note = note
        self.created_by = created_by
        self.flag_count = flag_count
        self.analyzing_count = analyzing_count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagEdit(Model):
    """FlagEdit.

    :param flag_type_id: Type of the flag
     Note: Audit exception flag type id cannot be assigned manually <span
     class='property-internal'>Required (defined)</span>
    :type flag_type_id: int
    :param flag_status_id: Current status of the flag <span
     class='property-internal'>One of 1, 2 </span> <span
     class='property-internal'>Required (defined)</span>
    :type flag_status_id: int
    :param cost_recovery: Cost recovery associated with the issue this flag
     represents <span class='property-internal'>Required (defined)</span>
    :type cost_recovery: float
    :param comment: Event and action that has occurred with this flag <span
     class='property-internal'>Required (defined)</span>
    :type comment: str
    :param assignees: All users currently assigned to this flag <span
     class='property-internal'>Required (defined)</span>
    :type assignees: list[int]
    :param release_export_hold: Determines whether or not the bill will be
     released from export hold when resolving the bill flag
     This property cannot be true if HoldFromExport is true. <span
     class='property-internal'>Required (defined)</span>
    :type release_export_hold: bool
    :param hold_from_export: Determines whether or not the bill will be held
     for export when flagging the bill
     This property cannot be true if ReleaseExportHold is true. <span
     class='property-internal'>Required (defined)</span>
    :type hold_from_export: bool
    """

    _attribute_map = {
        'flag_type_id': {'key': 'flagTypeId', 'type': 'int'},
        'flag_status_id': {'key': 'flagStatusId', 'type': 'int'},
        'cost_recovery': {'key': 'costRecovery', 'type': 'float'},
        'comment': {'key': 'comment', 'type': 'str'},
        'assignees': {'key': 'assignees', 'type': '[int]'},
        'release_export_hold': {'key': 'releaseExportHold', 'type': 'bool'},
        'hold_from_export': {'key': 'holdFromExport', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(FlagEdit, self).__init__(**kwargs)
        self.flag_type_id = kwargs.get('flag_type_id', None)
        self.flag_status_id = kwargs.get('flag_status_id', None)
        self.cost_recovery = kwargs.get('cost_recovery', None)
        self.comment = kwargs.get('comment', None)
        self.assignees = kwargs.get('assignees', None)
        self.release_export_hold = kwargs.get('release_export_hold', None)
        self.hold_from_export = kwargs.get('hold_from_export', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BulkMeterCostAvoidanceSettings(Model):
    """BulkMeterCostAvoidanceSettings.

    :param attempt_cooling_adjustment: Indicates whether or not the cost
     avoidance processor will attempt cooling adjustments <span
     class='property-internal'>Required (defined)</span>
    :type attempt_cooling_adjustment: bool
    :param attempt_heating_adjustment: Indicates whether or not the cost
     avoidance processor will attempt heating adjustments <span
     class='property-internal'>Required (defined)</span>
    :type attempt_heating_adjustment: bool
    :param num_baseline_months: Determines number of months of data included
     in the meter's cost avoidance baseline <span
     class='property-internal'>Must be between 12 and 36</span> <span
     class='property-internal'>Required (defined)</span>
    :type num_baseline_months: int
    :param baseline_start_date: Determines the start date of the meter's cost
     avoidance baseline <span class='property-internal'>Must be between
     12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required
     (defined)</span>
    :type baseline_start_date: datetime
    :param cooling_needed_above: Determines the external temperature above
     which cooling is expected to take place <span
     class='property-internal'>Required (defined)</span>
    :type cooling_needed_above: int
    :param heating_needed_below: Determines the external temperature below
     which heating is expected to take place <span
     class='property-internal'>Required (defined)</span>
    :type heating_needed_below: int
    :param include_meter_in_cost_avoidance: Determines whether or not to
     include the meter in cost avoidance processing <span
     class='property-internal'>Required (defined)</span>
    :type include_meter_in_cost_avoidance: bool
    :param savings_start_date: Determines the start date after which energy
     and cost savings are expected to accrue <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     <span class='property-internal'>Required (defined)</span>
    :type savings_start_date: datetime
    :param filters: Filter criteria which determine the meters whose cost
     avoidance settings will be updated <span
     class='property-internal'>Required (defined)</span>
    :type filters: list[~energycap.sdk.models.FilterEdit]
    """

    _validation = {
        'num_baseline_months': {'maximum': 36, 'minimum': 12},
    }

    _attribute_map = {
        'attempt_cooling_adjustment': {'key': 'attemptCoolingAdjustment', 'type': 'bool'},
        'attempt_heating_adjustment': {'key': 'attemptHeatingAdjustment', 'type': 'bool'},
        'num_baseline_months': {'key': 'numBaselineMonths', 'type': 'int'},
        'baseline_start_date': {'key': 'baselineStartDate', 'type': 'iso-8601'},
        'cooling_needed_above': {'key': 'coolingNeededAbove', 'type': 'int'},
        'heating_needed_below': {'key': 'heatingNeededBelow', 'type': 'int'},
        'include_meter_in_cost_avoidance': {'key': 'includeMeterInCostAvoidance', 'type': 'bool'},
        'savings_start_date': {'key': 'savingsStartDate', 'type': 'iso-8601'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
    }

    def __init__(self, *, attempt_cooling_adjustment: bool=None, attempt_heating_adjustment: bool=None, num_baseline_months: int=None, baseline_start_date=None, cooling_needed_above: int=None, heating_needed_below: int=None, include_meter_in_cost_avoidance: bool=None, savings_start_date=None, filters=None, **kwargs) -> None:
        super(BulkMeterCostAvoidanceSettings, self).__init__(**kwargs)
        self.attempt_cooling_adjustment = attempt_cooling_adjustment
        self.attempt_heating_adjustment = attempt_heating_adjustment
        self.num_baseline_months = num_baseline_months
        self.baseline_start_date = baseline_start_date
        self.cooling_needed_above = cooling_needed_above
        self.heating_needed_below = heating_needed_below
        self.include_meter_in_cost_avoidance = include_meter_in_cost_avoidance
        self.savings_start_date = savings_start_date
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApprovalWorkflowRequestChild(Model):
    """ApprovalWorkflowRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param confirm_edit_delete: Required.  <span
     class='property-internal'>Required</span>
    :type confirm_edit_delete: bool
    """

    _validation = {
        'confirm_edit_delete': {'required': True},
    }

    _attribute_map = {
        'confirm_edit_delete': {'key': 'confirmEditDelete', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ApprovalWorkflowRequestChild, self).__init__(**kwargs)
        self.confirm_edit_delete = kwargs.get('confirm_edit_delete', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherImportResult(Model):
    """WeatherImportResult.

    :param begin_date: The begin date of the weather data that was imported
    :type begin_date: datetime
    :param end_date: The end date of the weather data that was imported
    :type end_date: datetime
    :param weather_station_summaries: List of weather stations and the number
     of readings that were imported for each
    :type weather_station_summaries:
     list[~energycap.sdk.models.WeatherStationSummary]
    """

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'weather_station_summaries': {'key': 'weatherStationSummaries', 'type': '[WeatherStationSummary]'},
    }

    def __init__(self, **kwargs):
        super(WeatherImportResult, self).__init__(**kwargs)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.weather_station_summaries = kwargs.get('weather_station_summaries', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TemplateVersion(Model):
    """TemplateVersion.

    :param template_id: The identifier for the template
    :type template_id: int
    :param version_id: The identifier for the template version
    :type version_id: int
    :param begin_date: The begin date of the template version
    :type begin_date: datetime
    :param end_date: The end date of the template version
    :type end_date: datetime
    :param template_lines: An array of template lines belonging to the
     template version
    :type template_lines: list[~energycap.sdk.models.TemplateLine]
    """

    _attribute_map = {
        'template_id': {'key': 'templateId', 'type': 'int'},
        'version_id': {'key': 'versionId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'template_lines': {'key': 'templateLines', 'type': '[TemplateLine]'},
    }

    def __init__(self, *, template_id: int=None, version_id: int=None, begin_date=None, end_date=None, template_lines=None, **kwargs) -> None:
        super(TemplateVersion, self).__init__(**kwargs)
        self.template_id = template_id
        self.version_id = version_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.template_lines = template_lines



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyEditRequest(Model):
    """ApiKeyEditRequest.

    All required parameters must be populated in order to send to Azure.

    :param api_key_name: Required. The name of the API key <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 60 characters</span>
    :type api_key_name: str
    :param api_key_description: A description for the API key <span
     class='property-internal'>Required (defined)</span>
    :type api_key_description: str
    """

    _validation = {
        'api_key_name': {'required': True, 'max_length': 60, 'min_length': 0},
    }

    _attribute_map = {
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
    }

    def __init__(self, *, api_key_name: str, api_key_description: str=None, **kwargs) -> None:
        super(ApiKeyEditRequest, self).__init__(**kwargs)
        self.api_key_name = api_key_name
        self.api_key_description = api_key_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentCreate(Model):
    """SpecialAdjustmentCreate.

    All required parameters must be populated in order to send to Azure.

    :param special_adjustment_method_id: Required. Special adjustment method
     identifier <span class='property-internal'>Required</span>
    :type special_adjustment_method_id: int
    :param comments: Required. Reason for making the special adjustment <span
     class='property-internal'>Required</span>
    :type comments: str
    :param value: Amount
     See special adjustment method list for acceptable precision
     Precision of -1 means the value should not be passed in
    :type value: float
    :param special_adjustment_type_id: Required. Special adjustment type
     identifier <span class='property-internal'>Required</span>
    :type special_adjustment_type_id: int
    :param frequency: Required. Frequency type <span
     class='property-internal'>One of Recurring, Continuous </span> <span
     class='property-internal'>Required</span>
    :type frequency: str
    :param start_date: Required. Start date <span
     class='property-internal'>Required</span>
    :type start_date: datetime
    :param end_date: Required. End date <span
     class='property-internal'>Required</span>
    :type end_date: datetime
    :param annual_cycle_start_mmdd: Frequency start period
     Should only be passed when Frequency type is Recurring <span
     class='property-internal'>Required when frequency is set to
     recurring</span>
    :type annual_cycle_start_mmdd: int
    :param annual_cycle_end_mmdd: Frequency end period
     Should only be passed when Frequency type is Recurring <span
     class='property-internal'>Required when frequency is set to
     recurring</span>
    :type annual_cycle_end_mmdd: int
    """

    _validation = {
        'special_adjustment_method_id': {'required': True},
        'comments': {'required': True},
        'special_adjustment_type_id': {'required': True},
        'frequency': {'required': True},
        'start_date': {'required': True},
        'end_date': {'required': True},
    }

    _attribute_map = {
        'special_adjustment_method_id': {'key': 'specialAdjustmentMethodId', 'type': 'int'},
        'comments': {'key': 'comments', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
        'special_adjustment_type_id': {'key': 'specialAdjustmentTypeId', 'type': 'int'},
        'frequency': {'key': 'frequency', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'annual_cycle_start_mmdd': {'key': 'annualCycleStartMMDD', 'type': 'int'},
        'annual_cycle_end_mmdd': {'key': 'annualCycleEndMMDD', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(SpecialAdjustmentCreate, self).__init__(**kwargs)
        self.special_adjustment_method_id = kwargs.get('special_adjustment_method_id', None)
        self.comments = kwargs.get('comments', None)
        self.value = kwargs.get('value', None)
        self.special_adjustment_type_id = kwargs.get('special_adjustment_type_id', None)
        self.frequency = kwargs.get('frequency', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.annual_cycle_start_mmdd = kwargs.get('annual_cycle_start_mmdd', None)
        self.annual_cycle_end_mmdd = kwargs.get('annual_cycle_end_mmdd', None)
